@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: customers.php,v 1.1.1.1 2005/06/30 05:03:55 ryu Exp $
+  $Id: customers.php,v 1.3 2006/06/14 11:56:51 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -35,6 +35,10 @@
         $customers_gender = tep_db_prepare_input($HTTP_POST_VARS['customers_gender']);
         $customers_dob = tep_db_prepare_input($HTTP_POST_VARS['customers_dob']);
 
+        $customers_firstname_kana = tep_db_prepare_input($HTTP_POST_VARS['customers_firstname_kana']);
+        $customers_lastname_kana = tep_db_prepare_input($HTTP_POST_VARS['customers_lastname_kana']);
+
+        
         $sql_data_array = array('customers_firstname' => $customers_firstname,
                                 'customers_lastname' => $customers_lastname,
                                 'customers_email_address' => $customers_email_address,
@@ -44,6 +48,10 @@
 
         if (ACCOUNT_GENDER == 'true') $sql_data_array['customers_gender'] = $customers_gender;
         if (ACCOUNT_DOB == 'true') $sql_data_array['customers_dob'] = tep_date_raw($customers_dob);
+        if (KN_CFG_ACCOUNT_NAME_KANA == 'true') {
+          $sql_data_array['customers_firstname_kana'] = $customers_firstname_kana;
+          $sql_data_array['customers_lastname_kana'] = $customers_lastname_kana;
+        }
 
         tep_db_perform(TABLE_CUSTOMERS, $sql_data_array, 'update', "customers_id = '" . tep_db_input($customers_id) . "'");
 
@@ -158,6 +166,12 @@ function check_form() {
 
   var customers_firstname = document.customers.customers_firstname.value;
   var customers_lastname = document.customers.customers_lastname.value;
+<?php
+  if (KN_CFG_ACCOUNT_NAME_KANA == 'true') {
+    echo 'var customers_firstname_kana = document.customers.customers_firstname_kana.value;' . "\n";
+    echo 'var customers_lastname_kana = document.customers.customers_lastname_kana.value;' . "\n";
+  }
+?>
 <?php if (ACCOUNT_COMPANY == 'true') echo 'var entry_company = document.customers.entry_company.value;' . "\n"; ?>
 <?php if (ACCOUNT_DOB == 'true') echo 'var customers_dob = document.customers.customers_dob.value;' . "\n"; ?>
   var customers_email_address = document.customers.customers_email_address.value;  
@@ -265,7 +279,7 @@ function check_form() {
     <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
 <?php
   if ($HTTP_GET_VARS['action'] == 'edit') {
-    $customers_query = tep_db_query("select c.customers_gender, c.customers_firstname, c.customers_lastname, c.customers_dob, c.customers_email_address, a.entry_company, a.entry_street_address, a.entry_suburb, a.entry_postcode, a.entry_city, a.entry_state, a.entry_zone_id, a.entry_country_id, c.customers_telephone, c.customers_fax, c.customers_newsletter, c.customers_default_address_id from " . TABLE_CUSTOMERS . " c left join " . TABLE_ADDRESS_BOOK . " a on c.customers_default_address_id = a.address_book_id where a.customers_id = c.customers_id and c.customers_id = '" . $HTTP_GET_VARS['cID'] . "'");
+    $customers_query = tep_db_query("select c.customers_gender, c.customers_firstname, c.customers_lastname, c.customers_firstname_kana, c.customers_lastname_kana, c.customers_dob, c.customers_email_address, a.entry_company, a.entry_street_address, a.entry_suburb, a.entry_postcode, a.entry_city, a.entry_state, a.entry_zone_id, a.entry_country_id, c.customers_telephone, c.customers_fax, c.customers_newsletter, c.customers_default_address_id from " . TABLE_CUSTOMERS . " c left join " . TABLE_ADDRESS_BOOK . " a on c.customers_default_address_id = a.address_book_id where a.customers_id = c.customers_id and c.customers_id = '" . $HTTP_GET_VARS['cID'] . "'");
     $customers = tep_db_fetch_array($customers_query);
     $cInfo = new objectInfo($customers);
 
@@ -288,6 +302,14 @@ function check_form() {
     $a_value = tep_draw_input_field('customers_lastname', $cInfo->customers_lastname, 'maxlength="32"', true);
     $address_form->setFormLine('lastname',ENTRY_LAST_NAME,$a_value);
 
+    // firstname_kana
+    $a_value = tep_draw_input_field('customers_firstname_kana', $cInfo->customers_firstname_kana, 'maxlength="48"', true);
+    $address_form->setFormLine('firstname_kana',ENTRY_FIRST_NAME_KANA,$a_value);
+
+    // lastname_kana
+    $a_value = tep_draw_input_field('customers_lastname_kana', $cInfo->customers_lastname_kana, 'maxlength="48"', true);
+    $address_form->setFormLine('lastname_kana',ENTRY_LAST_NAME_KANA,$a_value);
+
     // dob
     $a_value = tep_draw_input_field('customers_dob', tep_date_short($cInfo->customers_dob), 'maxlength="10"', true);
     $address_form->setFormLine('dob',ENTRY_DATE_OF_BIRTH,$a_value);
@@ -407,6 +429,9 @@ function check_form() {
           </tr>
         </table></td>
       </tr>
+<?php
+    if (KN_CFG_ACCOUNT_NEWSLETTER == 'true') {
+?>
       <tr>
         <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
       </tr>
@@ -421,6 +446,9 @@ function check_form() {
           </tr>
         </table></td>
       </tr>
+<?php
+    }
+?>
       <tr>
         <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
       </tr>
