@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: general.php,v 1.1.1.1 2005/06/30 05:04:06 ryu Exp $
+  $Id: general.php,v 1.2 2006/01/29 14:49:22 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -1230,20 +1230,13 @@
   }
 
 // Calculates Tax rounding the result
-// BOF koshoten.net-2.0.4 ǤüԶб
-/*
   function tep_calculate_tax($price, $tax) {
     global $currencies;
 
-    return tep_round($price * $tax / 100, $currencies->currencies[DEFAULT_CURRENCY]['decimal_places']);
-  }
-*/
-  function tep_calculate_tax($price, $tax) {
-    global $currencies;
+  // return tep_round($price * $tax / 100, $currencies->currencies[DEFAULT_CURRENCY]['decimal_places']);
     return $currencies->round_off($price * $tax / 100);
   }
-// EOF koshoten.net-2.0.4 ǤüԶб
-  
+
 ////
 // Returns the tax rate for a zone / class
 // TABLES: tax_rates, zones_to_geo_zones
