@@ -46,7 +46,7 @@ ryuhei@secondbrain.co.jp
       $titledata = fopen(FILENAME_P_T_INFILE, "w");
       $products_query = tep_db_query("select p.products_id, p.products_model, p.products_image, p.products_isbn, p.products_price, p.manufacturers_id, p.products_tax_class_id, IF(s.status, s.specials_new_products_price, NULL) as specials_new_products_price, pd.products_name, pd.products_subtitle, pd.products_series_title, pd.products_author, pd.products_publishers, pd.products_published, pd.products_volume, pd.products_description, pd.products_description2, pd.products_keywords from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd left join " . TABLE_SPECIALS . " s on p.products_id = s.products_id where p.products_status = '1' and pd.products_id = p.products_id and pd.language_id = '" . $languages_id . "'");
       while ($products = tep_db_fetch_array($products_query)) {
-        $product_contents_id = "[" . $products['products_id'] . "]";
+        $product_contents_id = "<::" . $products['products_id'] . "::>";
         $product_contents = "";
         for ($i = 0, $n = sizeof($mw_products_field); $i < $n; $i++) {
           $mw_products_field[$i]['weight'] = (int)$HTTP_POST_VARS[$mw_products_field[$i]['field'] . '_weight'];
@@ -202,27 +202,8 @@ ryuhei@secondbrain.co.jp
       fclose($indata);
       fclose($titledata);
         
-      // ʬϤμ¹
-      exec(FILENAME_MAKEWAM_JP . ' ' . DIR_FS_GETA_WORK . ' ' . FILENAME_P_INDATA . ' ' . FILENAME_P_OUTDATA);
-      // и٥եκ
-      $outdata = fopen(FILENAME_P_OUTDATA, "r");
-      $freqfile = fopen(FILENAME_P_FREQFILE, "w");
-      while (!feof($outdata)) {
-        $csv_rec = fgetcsv($outdata, 2000);
-        if ((empty($csv_rec)) || (!is_array($csv_rec))) {
-          continue;								// ԤȤΤʤǡɤФ
-        }
-        $column_name = array_shift($csv_rec);
-        $column_name = str_replace("[", '@', $column_name);
-        $column_name = str_replace("]", "", $column_name);
-        fwrite($freqfile, $column_name . "\n");
-        $freq_array = array_count_values($csv_rec);
-        foreach ($freq_array as $key => $value) {
-          fwrite($freqfile, $value . ' ' . $key . "\n");
-        }
-      }
-      fclose($outdata);
-      fclose($freqfile);
+      // ʬϤμ¹ԡ٥եκ
+      exec(FILENAME_MAKEWAM_JP . ' ' . DIR_FS_GETA_WORK . ' ' . FILENAME_P_INDATA . ' ' . FILENAME_P_FREQFILE);
       // WAM
       exec(FILENAME_MKW . ' ' . TEXT_P_HANDLE_ID . ' ' . DIR_FS_GETA_WORK . ' ' . FILENAME_P_FREQFILE);
       exec(FILENAME_MKAUX . ' ' . TEXT_P_HANDLE_ID . ' ' . DIR_FS_GETA_WORK . ' ' . FILENAME_P_T_INFILE);
