@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: orders.php,v 1.2 2006/03/27 04:49:25 ryu Exp $
+  $Id: orders.php,v 1.3 2006/08/13 08:58:12 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -229,7 +229,7 @@
               if (KN_CFG_USE_AUTHOR == 'true') {
                 $reservation_list .= EMAIL_TEXT_AUTHOR . '  ' . $order->products[$i]['author'] . "\n";
               }
-              if (KN_CFG_USE_VOLUME == 'ture') {
+              if (KN_CFG_USE_VOLUME == 'true') {
                 $reservation_list .= EMAIL_TEXT_VOLUME . '  ' . $order->products[$i]['volume'] . "\n";
               }
               if (KN_CFG_USE_ISBN == 'true') {
@@ -238,7 +238,7 @@
               if (KN_CFG_USE_PUBLISHERS == 'true') {
                 $reservation_list .= EMAIL_TEXT_PUBLISHERS . '  ' . $order->products[$i]['publishers'] . "\n";
               }
-              if (KN_CFG_USE_PUBLISHED == 'ture') {
+              if (KN_CFG_USE_PUBLISHED == 'true') {
                 $reservation_list .= EMAIL_TEXT_PUBLISHED . '  ' . $order->products[$i]['published'] . "\n";
               }
               $reservation_list .= EMAIL_TEXT_DESCRIPTION . '   ' . $order->products[$i]['description'] . "\n";
