@@ -747,7 +747,7 @@ ryuhei@secondbrain.co.jp
       }
       if (KN_CFG_USE_MANUFACTURERS != '') {
         $manufacturers_array = array(array('id' => '', 'text' => TEXT_NONE));
-        $manufacturers_query = tep_db_query("select manufacturers_id, manufacturers_name from " . TABLE_MANUFACTURERS . " order by manufacturers_name");
+        $manufacturers_query = tep_db_query("select manufacturers_id, manufacturers_name from " . TABLE_MANUFACTURERS . " order by sort_order");
         while ($manufacturers = tep_db_fetch_array($manufacturers_query)) {
           $manufacturers_array[] = array('id' => $manufacturers['manufacturers_id'],
                                          'text' => $manufacturers['manufacturers_name']);
@@ -893,7 +893,7 @@ ryuhei@secondbrain.co.jp
         <td><?php echo tep_draw_hidden_field('products_id', $HTTP_POST_VARS['products_id']) .  tep_draw_hidden_field('products_tax_class_id', $HTTP_POST_VARS['products_tax_class_id']); ?><table class="knEditTable" width="80%">
           <tr>
             <td class="knEditTableHeading" width="20%"><?php echo TEXT_PRODUCTS_MODEL; ?></td>
-            <td><?php echo ($HTTP_POST_VARS['p_model_auto_num'] ? TEXT_AUTO_NUM : $HTTP_POST_VARS['products_model']) . tep_draw_hidden_field('products_model', $HTTP_POST_VARS['products_model']) . tep_draw_hidden_field('categories_id', $HTTP_POST_VARS['p_model_auto_num']); ?></td>
+            <td><?php echo ($HTTP_POST_VARS['p_model_auto_num'] ? TEXT_AUTO_NUM : $HTTP_POST_VARS['products_model']) . tep_draw_hidden_field('products_model', $HTTP_POST_VARS['products_model']) . tep_draw_hidden_field('p_model_auto_num', $HTTP_POST_VARS['p_model_auto_num']); ?></td>
           </tr>
           <tr>
             <td class="knEditTableHeading"><?php echo TEXT_CATEGORIES; ?></td>
@@ -1181,7 +1181,7 @@ ryuhei@secondbrain.co.jp
 <?php
       if (KN_CFG_USE_MANUFACTURERS != '') {
         $manufacturers_array = array(array('id' => '', 'text' => TEXT_NONE));
-        $manufacturers_query = tep_db_query("select manufacturers_id, manufacturers_name from " . TABLE_MANUFACTURERS . " order by manufacturers_name");
+        $manufacturers_query = tep_db_query("select manufacturers_id, manufacturers_name from " . TABLE_MANUFACTURERS . " order by sort_order");
         while ($manufacturers = tep_db_fetch_array($manufacturers_query)) {
           $manufacturers_array[] = array('id' => $manufacturers['manufacturers_id'],
                                          'text' => $manufacturers['manufacturers_name']);
