@@ -670,7 +670,7 @@ ryuhei@secondbrain.co.jp
               if ($cfg_rec[1] == $field_check[$i]['id']) {
                 $cfg_field = $field_check[$i]['field'];
                 if (($cfg_field == 'categories_id') && ($cfg_rec[2] == 'NAME')) {
-                  $cname_flg = ture;
+                  $cname_flg = true;
                   // ƥ꡼̾ѥƥ꡼ꥹȺ
                   $categories_id_array = array();
                   $categories_query = tep_db_query("select c.categories_id, cd.categories_name from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.categories_id = cd.categories_id and cd.language_id='" . tep_db_prepare_input($HTTP_POST_VARS['language_id']) ."'");
@@ -679,7 +679,7 @@ ryuhei@secondbrain.co.jp
                   }
                 }
                 if (($cfg_field == 'manufacturers_id') && ($cfg_rec[2] == 'NAME')) {
-                  $mname_flg = ture;
+                  $mname_flg = true;
                   // ᡼̾ѥ᡼ꥹȺ
                   $manufacturers_id_array = array();
                   $manufacturers_query = tep_db_query("select manufacturers_id, manufacturers_name from " . TABLE_MANUFACTURERS);
@@ -1357,7 +1357,7 @@ switch ($HTTP_GET_VARS['action']) {
         <td WIDTH="100%" class="main">
 <?PHP
         // ɥǡθ
-        echo TEXT_UPFILE_LANGUAGE . '&nbsp;&nbsp;';
+        echo TEXT_DOWNLOAD_LANGUAGE . '&nbsp;&nbsp;';
         $languages = tep_get_languages();
         for ($i = 0, $n = sizeof($languages); $i < $n; $i++) {
           if ($languages[$i]['code'] == DEFAULT_LANGUAGE) {
