@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: account_edit_process.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
+  $Id: account_edit_process.php,v 1.6 2006/08/07 06:21:15 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -38,6 +38,8 @@
   $gender = tep_db_prepare_input($HTTP_POST_VARS['gender']);
   $firstname = tep_db_prepare_input($HTTP_POST_VARS['firstname']);
   $lastname = tep_db_prepare_input($HTTP_POST_VARS['lastname']);
+  $firstname_kana = tep_db_prepare_input($HTTP_POST_VARS['firstname_kana']);
+  $lastname_kana = tep_db_prepare_input($HTTP_POST_VARS['lastname_kana']);
   $dob = tep_db_prepare_input($HTTP_POST_VARS['dob']);
   $email_address = tep_db_prepare_input($HTTP_POST_VARS['email_address']);
   $telephone = tep_db_prepare_input($HTTP_POST_VARS['telephone']);
@@ -196,49 +198,67 @@
     $breadcrumb->add(NAVBAR_TITLE_1, tep_href_link(FILENAME_ACCOUNT, '', 'SSL'));
     $breadcrumb->add(NAVBAR_TITLE_2, tep_href_link(FILENAME_ACCOUNT_EDIT, '', 'SSL'));
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
 <title><?php echo TITLE; ?></title>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_ACCOUNT_EDIT_PROCESS, 0, strrpos(FILENAME_ACCOUNT_EDIT_PROCESS, '.'));?>.css">
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_ACCOUNT_EDIT_PROCESS, 0, strrpos(FILENAME_ACCOUNT_EDIT_PROCESS, '.'));?>.css" media="screen,print" />
 <?php require('includes/form_check.js.php'); ?>
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+<!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-<!-- body //-->
-<table id="contents">
-  <tr>
-<!-- left_navigation //-->
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents"><?php echo tep_draw_form('account_edit', tep_href_link(FILENAME_ACCOUNT_EDIT_PROCESS, '', 'SSL'), 'post', 'onSubmit="return check_form();"') . tep_draw_hidden_field('action', 'process'); ?>
-      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
-<?php include(DIR_WS_MODULES . 'account_details.php'); ?>
-      <table>
-        <tr class="buttonLine">
-          <td class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_ACCOUNT, '', 'SSL') . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></td>
-          <td class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></td>
-        </tr>
-      </table>
-    </form></td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-<!-- footer //-->
-<?php include(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
+<?php
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
+  }
+?>
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
+<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
+<?php echo tep_draw_form('account_edit', tep_href_link(FILENAME_ACCOUNT_EDIT_PROCESS, '', 'SSL'), 'post', 'onSubmit="return check_form();"') . tep_draw_hidden_field('action', 'process') . "\n"; ?>
+<div id="account">
+<?php include(DIR_WS_MODULES . 'account_details.php'); ?>
+<div class="buttonLine">
+<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_ACCOUNT, '', 'SSL') . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
+<p class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
 </div>
+</div>
+</form>
+</div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php
@@ -253,6 +273,10 @@
 
     if (ACCOUNT_GENDER == 'true') $sql_data_array['customers_gender'] = $gender;
     if (ACCOUNT_DOB == 'true') $sql_data_array['customers_dob'] = tep_date_raw($dob);
+    if (KN_CFG_ACCOUNT_NAME_KANA == 'true') {
+      $sql_data_array['customers_firstname_kana'] = $firstname_kana;
+      $sql_data_array['customers_lastname_kana'] = $lastname_kana;
+    }
 
     tep_db_perform(TABLE_CUSTOMERS, $sql_data_array, 'update', "customers_id = '" . tep_db_input($customer_id) . "'");
 
