@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_confirmation_short.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
+  $Id: checkout_confirmation_short.php,v 1.5 2006/08/07 06:21:15 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -94,72 +94,87 @@
   $breadcrumb->add(NAVBAR_TITLE_1, tep_href_link(FILENAME_CHECKOUT_CONFIRMATION_SHORT, '', 'SSL'));
   $breadcrumb->add(NAVBAR_TITLE_2);
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
 <title><?php echo TITLE; ?></title>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CHECKOUT_CONFIRMATION_SHORT, 0, strrpos(FILENAME_CHECKOUT_CONFIRMATION_SHORT, '.'));?>.css">
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CHECKOUT_CONFIRMATION_SHORT, 0, strrpos(FILENAME_CHECKOUT_CONFIRMATION_SHORT, '.'));?>.css" media="screen,print" />
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+<!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-
-<!-- body //-->
-<table id="contents">
-  <tr>
-<!-- left_navigation //-->
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents">
-      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
+<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
+<?php
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
+  }
+?>
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
+<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
+<div id="checkout">
 <?php
   $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_CHECKOUT_CONFIRMATION'");
   $shop_info = tep_db_fetch_array($shop_info_query);
   if (isset($shop_info['shop_info_value']) && tep_not_null($shop_info['shop_info_value'])) {
-    echo '      <div id="siCheckoutConfirmation">';
+    echo '<div class="information"><p>';
     if ($shop_info['allow_tags']) {
       echo $shop_info['shop_info_value'];
     } else {
       echo nl2br(htmlspecialchars($shop_info['shop_info_value']));
     }
-    echo '      </div>';
+    echo "</p></div>\n";
   }
 ?>
-      <h3><?php echo HEADING_PRODUCTS_INFORMATION; ?></h3>
-      <table class="checkoutOrders">
+<h3><?php echo HEADING_PRODUCTS_INFORMATION; ?></h3>
+<p class="orderEdit"><?php echo '<a href="' . tep_href_link(FILENAME_SHOPPING_CART) . '">' . TEXT_EDIT . '</a>'; ?></p>
+<table class="productsTable">
 <?php
   if (sizeof($order->info['tax_groups']) > 1) {
 ?>
-      <thead>
-        <tr>
-          <th class="checkoutOrdersProductsCol" colspan="3"><?php echo '<span class="tableHeading">' . HEADING_PRODUCTS . '</span> <a href="' . tep_href_link(FILENAME_SHOPPING_CART) . '"><span class="orderEdit">(' . TEXT_EDIT . ')</span></a>'; ?></th>
-          <th class="checkoutOrdersTaxCol"><span class="tableHeading"><?php echo HEADING_TAX; ?></span></th>
-          <th class="checkoutOrdersPriceCol"><span class="tableHeading"><?php echo HEADING_TOTAL; ?></span></th>
-        </tr>
-      </thead>
-      <tbody>
+<tr>
+<th colspan="3"><?php echo HEADING_PRODUCTS; ?></th>
+<th><?php echo HEADING_TAX; ?></th>
+<th><?php echo HEADING_TOTAL; ?></th>
+</tr>
 <?php
   } else {
 ?>
-      <thead>
-        <tr>
-          <th class="checkoutOrdersProductsCol" colspan="4"><?php echo '<span class="tableHeading">' . HEADING_PRODUCTS . '</span> <a href="' . tep_href_link(FILENAME_SHOPPING_CART) . '"><span class="orderEdit">(' . TEXT_EDIT . ')</span></a>'; ?></th>
-        </tr>
-      </thead>
-      <tbody>
+<tr>
+<th colspan="4"><?php echo HEADING_PRODUCTS; ?></th>
+</tr>
 <?php
   }
 
   for ($i=0, $n=sizeof($order->products); $i<$n; $i++) {
-    echo '        <tr>' . "\n" .
-         '          <td class="checkoutOrdersQuantityCol">' . $order->products[$i]['qty'] . '&nbsp;x</td>' . "\n" .
-         '          <td class="checkoutOrdersProductsCol">' . $order->products[$i]['name'];
+    echo '<tr>' . "\n" .
+         '<td class="quantity"><p>' . $order->products[$i]['qty'] . '&nbsp;x</p></td>' . "\n" .
+         '<td class="product"><p>' . $order->products[$i]['name'];
 
     if (STOCK_CHECK == 'true') {
       echo tep_check_stock($order->products[$i]['id'], $order->products[$i]['qty']);
@@ -167,12 +182,12 @@
 
     if ( (isset($order->products[$i]['attributes'])) && (sizeof($order->products[$i]['attributes']) > 0) ) {
       for ($j=0, $n2=sizeof($order->products[$i]['attributes']); $j<$n2; $j++) {
-        echo '<br><span class="productOptions"> - ' . $order->products[$i]['attributes'][$j]['option'] . ': ' . $order->products[$i]['attributes'][$j]['value'] . '</span>';
+        echo '<br /><span class="options"> - ' . $order->products[$i]['attributes'][$j]['option'] . ': ' . $order->products[$i]['attributes'][$j]['value'] . '</span>';
       }
     }
 
-    echo '</td>' . "\n";
-    echo '          <td class="checkoutOrdersDescriptionCol">';
+    echo '</p></td>' . "\n";
+    echo '<td><p>';
     if ((KN_CFG_USE_SUBTITLE == 'true') && !empty($order->products[$i]['subtitle'])) {
       echo $order->products[$i]['subtitle'] . '&nbsp;';
     }
@@ -191,78 +206,64 @@
     if ((KN_CFG_USE_PUBLISHED == 'true') && !empty($order->products[$i]['published'])) {
       echo $order->products[$i]['published'] . '&nbsp;';
     }
-    echo $order->products[$i]['description'] . '</td>' . "\n";
+    echo $order->products[$i]['description'] . '</p></td>' . "\n";
 
-    if (sizeof($order->info['tax_groups']) > 1) echo '          <td class="checkoutOrdersTaxCol">' . tep_display_tax_value($order->products[$i]['tax']) . '%</td>' . "\n";
+    if (sizeof($order->info['tax_groups']) > 1) echo '<td class="tax"><p>' . tep_display_tax_value($order->products[$i]['tax']) . '%</p></td>' . "\n";
 
-    echo '          <td class="checkoutOrdersPriceCol">' . $currencies->display_price($order->products[$i]['final_price'], $order->products[$i]['tax'], $order->products[$i]['qty']) . '</td>' . "\n" .
-         '        </tr>' . "\n";
+    echo '<td class="price"><p>' . $currencies->display_price($order->products[$i]['final_price'], $order->products[$i]['tax'], $order->products[$i]['qty']) . '</p></td>' . "\n";
+    echo '</tr>' . "\n";
   }
-?>
-<?php
+  
+  echo "</table>\n";
+
   if (MODULE_ORDER_TOTAL_INSTALLED) {
-    if (sizeof($order->info['tax_groups']) > 1) {
-      echo '        <tr>';
-      echo '          <td colspan="5"><table class="checkoutOrdersTotal">';
-    } else {
-      echo '        <tr>';
-      echo '          <td colspan="4"><table class="checkoutOrdersTotal">';
-    }
     $order_total_modules->process();
-    echo $order_total_modules->output() . "</table>\n";
-    echo "</td>\n";
-    echo '        </tr>' . "\n";
+    echo $order_total_modules->output();
   }
 ?>
-      </tbody>
-      </table>
-      <h3><?php echo HEADING_CUSTOMER_INFORMATION; ?></h3>
-      <table class="checkoutCustomerInfo">
-        <tr>
-          <td class="checkoutCustomerInfoShipping"><table>
-            <tr><td><?php echo '<span class="tableHeading">' . HEADING_DELIVERY_ADDRESS . '</span> <a href="' . tep_href_link(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, '', 'SSL') . '"><span class="orderEdit">(' . TEXT_EDIT . ')</span></a>'; ?></td></tr>
-            <tr><td><?php echo tep_address_format($order->delivery['format_id'], $order->delivery, 1, ' ', '<br>'); ?></td></tr>
-          </table></td>
-          <td class="checkoutCustomerInfoPayment"><table>
-            <tr><td><?php echo '<span class="tableHeading">' . HEADING_BILLING_ADDRESS . '</span> <a href="' . tep_href_link(FILENAME_CHECKOUT_PAYMENT_ADDRESS_SHORT, '', 'SSL') . '"><span class="orderEdit">(' . TEXT_EDIT . ')</span></a>'; ?></td></tr>
-            <tr><td><?php echo tep_address_format($order->billing['format_id'], $order->billing, 1, ' ', '<br>'); ?></td></tr>
-          </table></td>
-        </tr>
-      </table>
-      <?php echo tep_draw_form('checkout_confirmation', tep_href_link(FILENAME_CHECKOUT_PROCESS, '', 'SSL'), 'post'); ?>
-      <h3 class="checkoutCommentsHeader"><?php echo HEADING_ORDER_COMMENTS; ?></h3>
-      <div class="checkoutComments"><?php echo tep_draw_textarea_field('comments', 'soft', '60', '5'); ?></div>
-      <table>
-        <tr class="buttonLine">
-          <td class="buttonRight"><?php echo tep_image_submit('button_confirm_order.gif', IMAGE_BUTTON_CONFIRM_ORDER);?></td>
-        </tr>
-      </table></form>
+<h3><?php echo HEADING_CUSTOMER_INFORMATION; ?></h3>
+<div id="contentsBox">
+<div id="leftBox">
+<h4><?php echo HEADING_DELIVERY_ADDRESS; ?></h4>
+<p class="orderEdit"><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, '', 'SSL') . '">' . TEXT_EDIT . '</a>'; ?></p>
+<p><?php echo tep_address_format($order->delivery['format_id'], $order->delivery, 1, ' ', '<br />'); ?></p>
+</div>
+<div id="rightBox">
+<h4><?php echo HEADING_BILLING_ADDRESS; ?></h4>
+<p class="orderEdit"><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_PAYMENT_ADDRESS_SHORT, '', 'SSL') . '">' . TEXT_EDIT . '</a>'; ?></p>
+<p><?php echo tep_address_format($order->billing['format_id'], $order->billing, 1, ' ', '<br />'); ?></p>
+</div>
+</div>
+<?php echo tep_draw_form('checkout_confirmation', tep_href_link(FILENAME_CHECKOUT_PROCESS, '', 'SSL'), 'post') . "\n"; ?>
+<h3><?php echo HEADING_ORDER_COMMENTS; ?></h3>
+<p><?php echo tep_draw_textarea_field('comments', 'soft', '60', '5'); ?></p>
+<div class="buttonLine">
+<p class="buttonRight"><?php echo tep_image_submit('button_confirm_order.gif', IMAGE_BUTTON_CONFIRM_ORDER);?></p>
+</div>
+</form>
 <?php
   $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_SHIPPING'");
   $shop_info = tep_db_fetch_array($shop_info_query);
   if (isset($shop_info['shop_info_value']) && tep_not_null($shop_info['shop_info_value'])) {
-    echo '      <div class="checkoutOrderNotesHeader">' . HEADING_ORDER_NOTES . '</div>' . "\n";
-    echo '      <div id="siShipping">';
+    echo '<h3>' . HEADING_ORDER_NOTES . '</h3>' . "\n";
+    echo '<p>';
     if ($shop_info['allow_tags']) {
       echo $shop_info['shop_info_value'];
     } else {
       echo nl2br(htmlspecialchars($shop_info['shop_info_value']));
     }
-    echo '      </div>' . "\n";
+    echo "</p>\n";
   }
  ?>
-    </td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
-<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-<!-- footer //-->
-<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
 </div>
+</div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
