@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_payment.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
+  $Id: checkout_payment.php,v 1.5 2006/08/07 06:21:15 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -90,14 +90,15 @@
   $breadcrumb->add(NAVBAR_TITLE_1, tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL'));
   $breadcrumb->add(NAVBAR_TITLE_2, tep_href_link(FILENAME_CHECKOUT_PAYMENT, '', 'SSL'));
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
 <title><?php echo TITLE; ?></title>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CHECKOUT_PAYMENT, 0, strrpos(FILENAME_CHECKOUT_PAYMENT, '.'));?>.css">
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CHECKOUT_PAYMENT, 0, strrpos(FILENAME_CHECKOUT_PAYMENT, '.'));?>.css" media="screen,print" />
 <script language="javascript"><!--
 var selected;
 
@@ -133,148 +134,152 @@ function rowOutEffect(object) {
 <?php echo $payment_modules->javascript_validation(); ?>
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+<!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-<!-- body //-->
-<table id="contents">
-  <tr>
-<!-- left_navigation //-->
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents"><?php echo tep_draw_form('checkout_payment', tep_href_link(FILENAME_CHECKOUT_CONFIRMATION, '', 'SSL'), 'post', 'onsubmit="return check_form();"'); ?>
-      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
+<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
+<?php
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
+  }
+?>
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
+<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
+<?php echo tep_draw_form('checkout_payment', tep_href_link(FILENAME_CHECKOUT_CONFIRMATION, '', 'SSL'), 'post', 'onsubmit="return check_form();"'); ?>
+<div id="checkout">
 <?php
   if (isset($HTTP_GET_VARS['payment_error']) && is_object(${$HTTP_GET_VARS['payment_error']}) && ($error = ${$HTTP_GET_VARS['payment_error']}->get_error())) {
 ?>
-      <div class="checkoutErrorHeader"><?php echo nl2br(htmlspecialchars($error['title'])); ?></div>
-      <div class="checkoutErrorContents">
-        <div class="checkoutErrorMessage"><?php echo nl2br(htmlspecialchars($error['error'])); ?></div>
-      </div>
+<p class="errorTitle"><?php echo nl2br(htmlspecialchars($error['title'])); ?></p>
+<p class="errorMessage"><?php echo nl2br(htmlspecialchars($error['error'])); ?></p>
 <?php
   }
 ?>
-      <div class="checkoutAddressHeader"><?php echo TABLE_HEADING_BILLING_ADDRESS; ?></div>
-      <div class="checkoutAddressConfirmation">
-        <div class="checkoutChooseDestination"><?php echo TEXT_SELECTED_BILLING_DESTINATION; ?></div>
-        <div class="checkoutAddressLabel"><?php echo tep_address_label($customer_id, $billto, true, ' ', '<br>'); ?></div>
-        <div class="checkoutChangeAddress"><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_PAYMENT_ADDRESS, '', 'SSL') . '">' . tep_image_button('button_change_address.gif', IMAGE_BUTTON_CHANGE_ADDRESS) . '</a>'; ?></div>
-      </div>
-      <div class="checkoutChooseModuleHeader"><?php echo TABLE_HEADING_PAYMENT_METHOD; ?></div>
-      <table class="checkoutModuleTable">
+<h3><?php echo TABLE_HEADING_BILLING_ADDRESS; ?></h3>
+<p><?php echo TEXT_SELECTED_BILLING_DESTINATION; ?></p>
+<p class="addressLabel"><?php echo tep_address_label($customer_id, $billto, true, ' ', '<br />'); ?></p>
+<p class="changeAddress"><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_PAYMENT_ADDRESS, '', 'SSL') . '">' . tep_image_button('button_change_address.gif', IMAGE_BUTTON_CHANGE_ADDRESS) . '</a>'; ?></p>
+<h3><?php echo TABLE_HEADING_PAYMENT_METHOD; ?></h3>
 <?php
   $selection = $payment_modules->selection();
 
   if (sizeof($selection) > 1) {
-?>
-      <thead>
-        <tr>
-          <th colspan="3"><?php echo TEXT_SELECT_PAYMENT_METHOD; ?></th>
-        </tr>
-      </thead>
-      <tbody>
-<?php
-  } else {
-?>
-      <thead>
-        <tr>
-          <th colspan="3"><?php echo TEXT_ENTER_PAYMENT_INFORMATION; ?></th>
-        </tr>
-      </thead>
-      <tbody>
-<?php
+    echo '<p>' . TEXT_SELECT_PAYMENT_METHOD . "</p>\n";
+  } elseif ($free_shipping == false) {
+    echo '<p>' .  TEXT_ENTER_PAYMENT_INFORMATION . "</p>\n";
   }
-
+?>
+<table class="moduleTable">
+<?php
   $radio_buttons = 0;
   for ($i=0, $n=sizeof($selection); $i<$n; $i++) {
     if ( ($selection[$i]['id'] == $payment) || ($n == 1) ) {
-      echo '        <tr id="defaultSelected" class="checkoutModuleRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
+      echo '<tr id="defaultSelected" class="checkoutModuleRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
     } else {
-      echo '        <tr class="checkoutModuleRow" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
+      echo '<tr class="checkoutModuleRow" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
     }
-?>
-          <td class="checkoutModuleTitle" colspan="2"><?php echo $selection[$i]['module']; ?></td>
-          <td class="checkoutModuleSelect">
-<?php
+
     if (sizeof($selection) > 1) {
-      echo tep_draw_radio_field('payment', $selection[$i]['id']) . "</td>\n";
+      echo '<th class="select">' . tep_draw_radio_field('payment', $selection[$i]['id']) . "</th>\n";
     } else {
-      echo tep_draw_hidden_field('payment', $selection[$i]['id']) . "</td>\n";
+      echo '<th class="select">' . tep_draw_hidden_field('payment', $selection[$i]['id']) . "</th>\n";
     }
 ?>
-        </tr>
+<th class="title" colspan="2"><?php echo $selection[$i]['module']; ?></th>
+</tr>
 <?php
     if (isset($selection[$i]['error'])) {
 ?>
-        <tr>
-          <td class="checkoutModuleError" colspan="3"><?php echo $selection[$i]['error']; ?></td>
-        </tr>
+<tr class="checkoutModuleRowFields">
+<td class="error" colspan="3"><?php echo $selection[$i]['error']; ?></td>
+</tr>
 <?php
     } elseif (isset($selection[$i]['fields']) && is_array($selection[$i]['fields'])) {
       for ($j=0, $n2=sizeof($selection[$i]['fields']); $j<$n2; $j++) {
 ?>
-        <tr>
-          <td class="checkoutModuleMethod"><?php echo $selection[$i]['fields'][$j]['title']; ?></td>
-          <td class="checkoutModuleField"><?php echo $selection[$i]['fields'][$j]['field']; ?></td>
-          <td class="checkoutModuleSelect"></td>
-        </tr>
+<tr class="checkoutModuleRowFields">
+<td class="select">&nbsp;</td>
+<?php
+        if ($selection[$i]['fields'][$j]['field']) {
+?>
+<td class="method"><?php echo $selection[$i]['fields'][$j]['title']; ?></td>
+<td class="field"><?php echo $selection[$i]['fields'][$j]['field']; ?></td>
+<?php
+        } else {
+?>
+<td class="method" colspan="2"><?php echo $selection[$i]['fields'][$j]['title']; ?></td>
+<?php
+        }
+?>
+</tr>
 <?php
       }
     }
     $radio_buttons++;
   }
 ?>
-      </tbody>
-      </table>
-      <div class="checkoutCommentsHeader"><?php echo TABLE_HEADING_COMMENTS; ?></div>
-      <div class="checkoutComments"><?php echo tep_draw_textarea_field('comments', 'soft', '60', '5') . tep_draw_hidden_field('comments_added', 'YES'); ?></div>
-      <div class="checkoutContinueCheckout">
-        <div class="checkoutContinueCheckoutTitle"><?php echo TITLE_CONTINUE_CHECKOUT_PROCEDURE; ?></div>
-        <div class="checkoutContinueCheckoutText"><?php echo TEXT_CONTINUE_CHECKOUT_PROCEDURE; ?></div>
-        <div class="checkoutContinueCheckoutButton"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></div>
-      </div>
-      <table class="checkoutBar">
-        <tr class="checkoutBarImage">
-          <td class="checkoutBarFrom"><?php echo tep_draw_separator('pixel_trans.gif', '100%', '1'); ?></td>
-          <td class="checkoutBarCurrent"><?php echo tep_image(DIR_WS_IMAGES . 'checkout_bullet.gif'); ?></td>
-          <td class="checkoutBarTo"><?php echo tep_draw_separator('pixel_trans.gif', '100%', '1'); ?></td>
-          <td class="checkoutBarTo"><?php echo tep_draw_separator('pixel_trans.gif', '100%', '1'); ?></td>
-        </tr>
-        <tr class="checkoutBarText">
-          <td class="checkoutBarFrom"><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL') . '"><span class="checkoutBarDelivery">' . CHECKOUT_BAR_DELIVERY . '</span></a>'; ?></td>
-          <td class="checkoutBarCurrent"><span class="checkoutBarPayment"><?php echo CHECKOUT_BAR_PAYMENT; ?></span></td>
-          <td class="checkoutBarTo"><span class="checkoutBarConfirmation"><?php echo CHECKOUT_BAR_CONFIRMATION; ?></span></td>
-          <td class="checkoutBarTo"><span class="checkoutBarFinished"><?php echo CHECKOUT_BAR_FINISHED; ?></span></td>
-        </tr>
-      </table>
+</table>
+<h3><?php echo TABLE_HEADING_COMMENTS; ?></h3>
+<p><?php echo tep_draw_textarea_field('comments', 'soft', '60', '5') . tep_draw_hidden_field('comments_added', 'YES'); ?></p>
+<div class="buttonLine">
+<p class="checkoutTitle"><?php echo TITLE_CONTINUE_CHECKOUT_PROCEDURE; ?></p>
+<p class="checkoutText"><?php echo TEXT_CONTINUE_CHECKOUT_PROCEDURE; ?></p>
+<p class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
+</div>
+<ul id="checkoutBar">
+<li class="from"><p><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL') . '">' . CHECKOUT_BAR_DELIVERY . '</a>'; ?></p></li>
+<li class="current">
+<p><?php echo tep_image(DIR_WS_IMAGES . 'checkout_bullet.gif'); ?></p>
+<p><?php echo CHECKOUT_BAR_PAYMENT; ?></p>
+</li>
+<li class="to"><p><?php echo CHECKOUT_BAR_CONFIRMATION; ?></p></li>
+<li class="to"><p><?php echo CHECKOUT_BAR_FINISHED; ?></p></li>
+</ul>
 <?php
   $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_SHIPPING'");
   $shop_info = tep_db_fetch_array($shop_info_query);
   if (isset($shop_info['shop_info_value']) && tep_not_null($shop_info['shop_info_value'])) {
-    echo '      <div class="checkoutOrderNotesHeader">' . HEADING_ORDER_NOTES . '</div>' . "\n";
-    echo '      <div id="siShipping">';
+    echo '<h3>' . HEADING_ORDER_NOTES . "</h3>\n";
+    echo '<p>';
     if ($shop_info['allow_tags']) {
       echo $shop_info['shop_info_value'];
     } else {
       echo nl2br(htmlspecialchars($shop_info['shop_info_value']));
     }
-    echo '      </div>' . "\n";
+    echo "</p>\n";
   }
- ?>
-    </form></td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
-<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-<!-- footer //-->
-<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
+?>
 </div>
+</form>
+</div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
