@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_process.php,v 1.5 2006/03/27 10:11:39 ryu Exp $
+  $Id: checkout_process.php,v 1.7 2006/06/13 12:52:33 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -347,7 +347,12 @@
   
   if (KN_CFG_MAIL_PRIVACY_DISPLAY == 'true') {
     $email_order .= "\n" . EMAIL_TEXT_CUSTOMER . "\n" . EMAIL_SEPARATOR . "\n";
-    $email_order .= EMAIL_TEXT_CUSTOMER_NAME . '  ' . tep_get_fullname($order->customer['firstname'],$order->customer['lastname']) . "\n";
+    $email_order .= EMAIL_TEXT_CUSTOMER_NAME . '  ' . tep_get_fullname($order->customer['firstname'],$order->customer['lastname']);
+    if ((KN_CFG_ACCOUNT_NAME_KANA == 'true') && ($language == 'japanese')) {
+      $email_order .=  '' . $order->customer['lastname_kana'] . ' ' . $order->customer['firstname_kana'] . "\n";
+    } else {
+      $email_order .=  "\n";
+    }
     $email_order .= EMAIL_TEXT_CUSTOMER_EMAIL_ADDRESS . '  ' . $order->customer['email_address'] . "\n";
     $email_order .= "\n" . EMAIL_TEXT_DELIVERY_ADDRESS . "\n" . 
                     EMAIL_SEPARATOR . "\n" .
@@ -361,12 +366,12 @@
       $email_order .= EMAIL_TEXT_PAYMENT_METHOD . "\n" . 
                       EMAIL_SEPARATOR . "\n";
       $payment_class = $$payment;
-      $email_order .= $payment_class->title . "\n\n";
+      $email_order .= $payment_class->title . "\n";
       if ($payment_class->email_footer) { 
-        $email_order .= $payment_class->email_footer . "\n";
+        $email_order .= $payment_class->email_footer . "\n\n";
       }
     } else {
-      $email_order .= "\n";
+      $email_order .= "\n\n";
     }
   } else {
     $email_order .= EMAIL_TEXT_INVOICE_URL . ' ' . tep_href_link(FILENAME_ACCOUNT_HISTORY_INFO, 'order_id=' . $insert_id, 'SSL', false) . "\n\n";
