@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_shipping.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
+  $Id: checkout_shipping.php,v 1.5 2006/08/07 06:21:15 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -161,14 +161,15 @@
   $breadcrumb->add(NAVBAR_TITLE_1, tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL'));
   $breadcrumb->add(NAVBAR_TITLE_2, tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL'));
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
 <title><?php echo TITLE; ?></title>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CHECKOUT_SHIPPING, 0, strrpos(FILENAME_CHECKOUT_SHIPPING, '.'));?>.css">
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CHECKOUT_SHIPPING, 0, strrpos(FILENAME_CHECKOUT_SHIPPING, '.'));?>.css" media="screen,print" />
 <script language="javascript"><!--
 var selected;
 
@@ -186,10 +187,10 @@ function selectRowEffect(object, buttonSelect) {
   selected = object;
 
 // one button is not an array
-  if (document.checkout_address.shipping[0]) {
-    document.checkout_address.shipping[buttonSelect].checked=true;
+  if (document.checkout_shipping.shipping[0]) {
+    document.checkout_shipping.shipping[buttonSelect].checked=true;
   } else {
-    document.checkout_address.shipping.checked=true;
+    document.checkout_shipping.shipping.checked=true;
   }
 }
 
@@ -203,77 +204,82 @@ function rowOutEffect(object) {
 //--></script>
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+<!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-
-<!-- body //-->
-<table id="contents">
-  <tr>
-<!-- left_navigation //-->
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents"><?php echo tep_draw_form('checkout_address', tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL')) . tep_draw_hidden_field('action', 'process'); ?>
-      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
-      <div class="checkoutAddressHeader"><?php echo TABLE_HEADING_SHIPPING_ADDRESS; ?></div>
-      <div class="checkoutAddressConfirmation">
-        <div class="checkoutChooseDestination"><?php echo TEXT_CHOOSE_SHIPPING_DESTINATION; ?></div>
-        <div class="checkoutAddressLabel"><?php echo tep_address_label($customer_id, $sendto, true, ' ', '<br>'); ?></div>
-        <div class="checkoutChangeAddress"><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_SHIPPING_ADDRESS, '', 'SSL') . '">' . tep_image_button('button_change_address.gif', IMAGE_BUTTON_CHANGE_ADDRESS) . '</a>'; ?></div>
-      </div>
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
+<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
+<?php
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
+  }
+?>
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
+<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
+<?php echo tep_draw_form('checkout_shipping', tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL')) . tep_draw_hidden_field('action', 'process') . "\n"; ?>
+<div id="checkout">
+<h3><?php echo TABLE_HEADING_SHIPPING_ADDRESS; ?></h3>
+<p><?php echo TEXT_CHOOSE_SHIPPING_DESTINATION; ?></p>
+<p class="addressLabel"><?php echo tep_address_label($customer_id, $sendto, true, ' ', '<br />'); ?></p>
+<p class="changeAddress"><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_SHIPPING_ADDRESS, '', 'SSL') . '">' . tep_image_button('button_change_address.gif', IMAGE_BUTTON_CHANGE_ADDRESS) . '</a>'; ?></p>
 <?php
   if (tep_count_modules(KN_CFG_MODULE_SHIPPING_INSTALLED) > 0) {
 ?>
-      <div class="checkoutChooseModuleHeader"><?php echo TABLE_HEADING_SHIPPING_METHOD; ?></div>
-      <table class="checkoutModuleTable">
+<h3><?php echo TABLE_HEADING_SHIPPING_METHOD; ?></h3>
 <?php
     if (sizeof($quotes) > 1) {
-?>
-      <thead>
-        <tr>
-          <th colspan="3"><?php echo TEXT_CHOOSE_SHIPPING_METHOD; ?></th>
-        </tr>
-      </thead>
-<?php
+      echo '<p>' . TEXT_CHOOSE_SHIPPING_METHOD . "</p>\n";
     } elseif ($free_shipping == false) {
-?>
-      <thead>
-        <tr>
-          <th colspan="3"><?php echo TEXT_ENTER_SHIPPING_INFORMATION; ?></th>
-        </tr>
-      </thead>
-<?php
+      echo '<p>' .  TEXT_ENTER_SHIPPING_INFORMATION . "</p>\n";
     }
 
     if ($free_shipping == true) {
 ?>
-      <tbody>
-        <tr>
-          <td class="checkoutModuleTitle" colspan="3"><?php echo FREE_SHIPPING_TITLE; ?></td>
-        </tr>
-        <tr id="defaultSelected" class="checkoutModuleRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, 0)">
-          <td class="checkoutModuleMethod" colspan="3"><?php echo sprintf(FREE_SHIPPING_DESCRIPTION, $currencies->format(MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER)) . tep_draw_hidden_field('shipping', 'free_free'); ?></td>
-        </tr>
-      </tbody>
+<table class="moduleTable">
+<tr>
+<td><?php echo FREE_SHIPPING_TITLE; ?></td>
+</tr>
+<tr id="defaultSelected" class="checkoutModuleRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, 0)">
+<td><?php echo sprintf(FREE_SHIPPING_DESCRIPTION, $currencies->format(MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER)) . tep_draw_hidden_field('shipping', 'free_free'); ?></td>
+</tr>
+</table>
 <?php
     } else {
 ?>
-      <tbody>
+<table class="moduleTable">
 <?php
       $radio_buttons = 0;
       for ($i=0, $n=sizeof($quotes); $i<$n; $i++) {
 ?>
-        <tr>
-          <td class="checkoutModuleTitle" colspan="3"><?php echo $quotes[$i]['module']; ?>&nbsp;<?php echo $quotes[$i]['icon']; ?></td>
-        </tr>
+<tr class="checkoutModuleRowFields">
+<th class="title" colspan="3"><?php echo $quotes[$i]['module']; ?>&nbsp;<?php echo $quotes[$i]['icon']; ?></th>
+</tr>
 <?php
         if (isset($quotes[$i]['error'])) {
 ?>
-        <tr>
-          <td class="checkoutModuleError" colspan="3"><?php echo $quotes[$i]['error']; ?></td>
-        </tr>
+<tr class="checkoutModuleRowFields">
+<td class="error" colspan="3"><?php echo $quotes[$i]['error']; ?></td>
+</tr>
 <?php
         } else {
           for ($j=0, $n2=sizeof($quotes[$i]['methods']); $j<$n2; $j++) {
@@ -281,86 +287,72 @@ function rowOutEffect(object) {
             $checked = (($quotes[$i]['id'] . '_' . $quotes[$i]['methods'][$j]['id'] == $shipping['id']) ? true : false);
 
             if ( ($quotes[$i]['id'] . '_' . $quotes[$i]['methods'][$j]['id'] == $shipping['id']) || (tep_count_modules(KN_CFG_MODULE_SHIPPING_INSTALLED) == (int)1) ) {
-              echo '        <tr id="defaultSelected" class="checkoutModuleRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
+              echo '<tr id="defaultSelected" class="checkoutModuleRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
             } else {
-              echo '        <tr class="checkoutModuleRow" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
+              echo '<tr class="checkoutModuleRow" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
             }
-?>
-          <td class="checkoutModuleMethod"><?php echo $quotes[$i]['methods'][$j]['title'].'&nbsp;&nbsp;'.$quotes[$i]['methods'][$j]['option']; ?></td>
-<?php
+
             if ( ($n > 1) || ($n2 > 1) ) {
-?>
-          <td class="checkoutModuleCost"><?php echo $currencies->format(tep_add_tax($quotes[$i]['methods'][$j]['cost'], $quotes[$i]['tax'])); ?></td>
-          <td class="checkoutModuleSelect"><?php echo tep_draw_radio_field('shipping', $quotes[$i]['id'] . '_' . $quotes[$i]['methods'][$j]['id'], $checked); ?></td>
-<?php
+              echo '<td class="select">' . tep_draw_radio_field('shipping', $quotes[$i]['id'] . '_' . $quotes[$i]['methods'][$j]['id'], $checked) . "</td>\n";
+              echo '<td class="method">' . $quotes[$i]['methods'][$j]['title'].'&nbsp;&nbsp;'.$quotes[$i]['methods'][$j]['option'] . "</td>\n";
+              echo '<td class="cost">' . $currencies->format(tep_add_tax($quotes[$i]['methods'][$j]['cost'], $quotes[$i]['tax'])) . "</td>\n";
             } else {
-?>
-          <td class="checkoutModuleCost" colspan="2"><?php echo $currencies->format(tep_add_tax($quotes[$i]['methods'][$j]['cost'], $quotes[$i]['tax'])) . tep_draw_hidden_field('shipping', $quotes[$i]['id'] . '_' . $quotes[$i]['methods'][$j]['id']); ?></td>
-<?php
+              echo '<td class="select">&nbsp;' . "</td>\n";
+              echo '<td class="method">' . $quotes[$i]['methods'][$j]['title'].'&nbsp;&nbsp;'.$quotes[$i]['methods'][$j]['option'] . "</td>\n";
+              echo '<td class="cost">' . $currencies->format(tep_add_tax($quotes[$i]['methods'][$j]['cost'], $quotes[$i]['tax'])) . tep_draw_hidden_field('shipping', $quotes[$i]['id'] . '_' . $quotes[$i]['methods'][$j]['id']) . "</td>\n";
             }
-?>
-        </tr>
-<?php
+            echo "</tr>\n";
+
             $radio_buttons++;
           }
         }
       }
-?>
-      </tbody>
-<?php
     }
 ?>
-      </table>
+</table>
 <?php
   }
 ?>
-      <div class="checkoutCommentsHeader"><?php echo TABLE_HEADING_COMMENTS; ?></div>
-      <div class="checkoutComments"><?php echo tep_draw_textarea_field('comments', 'soft', '60', '5') . tep_draw_hidden_field('comments_added', 'YES'); ?></div>
-      <div class="checkoutContinueCheckout">
-        <div class="checkoutContinueCheckoutTitle"><?php echo TITLE_CONTINUE_CHECKOUT_PROCEDURE; ?></div>
-        <div class="checkoutContinueCheckoutText"><?php echo TEXT_CONTINUE_CHECKOUT_PROCEDURE; ?></div>
-        <div class="checkoutContinueCheckoutButton"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></div>
-      </div>
-      <table class="checkoutBar">
-        <tr class="checkoutBarImage">
-          <td class="checkoutBarCurrent"><?php echo tep_image(DIR_WS_IMAGES . 'checkout_bullet.gif'); ?></td>
-          <td class="checkoutBarTo"><?php echo tep_draw_separator('pixel_trans.gif', '100%', '1'); ?></td>
-          <td class="checkoutBarTo"><?php echo tep_draw_separator('pixel_trans.gif', '100%', '1'); ?></td>
-          <td class="checkoutBarTo"><?php echo tep_draw_separator('pixel_trans.gif', '100%', '1'); ?></td>
-        </tr>
-        <tr class="checkoutBarText">
-          <td class="checkoutBarCurrent"><span class="checkoutBarDelivery"><?php echo CHECKOUT_BAR_DELIVERY; ?></span></td>
-          <td class="checkoutBarTo"><span class="checkoutBarPayment"><?php echo CHECKOUT_BAR_PAYMENT; ?></span></td>
-          <td class="checkoutBarTo"><span class="checkoutBarConfirmation"><?php echo CHECKOUT_BAR_CONFIRMATION; ?></span></td>
-          <td class="checkoutBarTo"><span class="checkoutBarFinished"><?php echo CHECKOUT_BAR_FINISHED; ?></span></td>
-        </tr>
-      </table>
+<h3><?php echo TABLE_HEADING_COMMENTS; ?></h3>
+<p><?php echo tep_draw_textarea_field('comments', 'soft', '60', '5') . tep_draw_hidden_field('comments_added', 'YES'); ?></p>
+<div class="buttonLine">
+<p class="checkoutTitle"><?php echo TITLE_CONTINUE_CHECKOUT_PROCEDURE; ?></p>
+<p class="checkoutText"><?php echo TEXT_CONTINUE_CHECKOUT_PROCEDURE; ?></p>
+<p class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
+</div>
+<ul id="checkoutBar">
+<li class="current">
+<p><?php echo tep_image(DIR_WS_IMAGES . 'checkout_bullet.gif'); ?></p>
+<p><?php echo CHECKOUT_BAR_DELIVERY; ?></p>
+</li>
+<li class="to"><p><?php echo CHECKOUT_BAR_PAYMENT; ?></p></li>
+<li class="to"><p><?php echo CHECKOUT_BAR_CONFIRMATION; ?></p></li>
+<li class="to"><p><?php echo CHECKOUT_BAR_FINISHED; ?></p></li>
+</ul>
 <?php
   $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_SHIPPING'");
   $shop_info = tep_db_fetch_array($shop_info_query);
   if (isset($shop_info['shop_info_value']) && tep_not_null($shop_info['shop_info_value'])) {
-    echo '      <div class="checkoutOrderNotesHeader">' . HEADING_ORDER_NOTES . '</div>' . "\n";
-    echo '      <div id="siShipping">';
+    echo '<h3>' . HEADING_ORDER_NOTES . "</h3>\n";
+    echo '<p>';
     if ($shop_info['allow_tags']) {
       echo $shop_info['shop_info_value'];
     } else {
       echo nl2br(htmlspecialchars($shop_info['shop_info_value']));
     }
-    echo '      </div>' . "\n";
+    echo "</p>\n";
   }
  ?>
-    </form></td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
-<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-<!-- footer //-->
-<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
 </div>
+</form>
+</div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
