@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_shipping_address_short.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
+  $Id: checkout_shipping_address_short.php,v 1.5 2006/08/07 06:21:15 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -122,7 +122,7 @@
       }
 
       if (ACCOUNT_STATE == 'true') {
-        if ($entry_country_error == true) {
+        if ($country_error == true) {
           $entry_state_error = true;
         } else {
           $zone_id = 0;
@@ -241,14 +241,15 @@
   $breadcrumb->add(NAVBAR_TITLE_1, tep_href_link(FILENAME_CHECKOUT_CONFIRMATION_SHORT, '', 'SSL'));
   $breadcrumb->add(NAVBAR_TITLE_2, tep_href_link(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, '', 'SSL'));
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
 <title><?php echo TITLE; ?></title>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, 0, strrpos(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, '.'));?>.css">
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, 0, strrpos(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, '.'));?>.css" media="screen,print" />
 <script language="javascript"><!--
 var selected;
 
@@ -290,7 +291,6 @@ function check_form() {
   var street_address = document.checkout_address.street_address.value;
   var postcode = document.checkout_address.postcode.value;
   var city = document.checkout_address.city.value;
-<?php // 2003-06-06 add_telephone ?>
   var telephone = document.checkout_address.telephone.value;
 
   if (firstname == '' && lastname == '' && street_address == '') {
@@ -350,7 +350,6 @@ function check_form() {
     error = 1;
   }
 
-<?php // 2003-06-06 add_telephone ?>
   if (telephone == '' || telephone.length < <?php echo ENTRY_TELEPHONE_MIN_LENGTH; ?>) {
     error_message = error_message + "<?php echo JS_TELEPHONE; ?>";
     error = 1;
@@ -366,50 +365,62 @@ function check_form() {
 //--></script>
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-<!-- body //-->
-<table id="contents">
-  <tr>
-<!-- left_navigation //-->
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents"><?php echo tep_draw_form('checkout_address', tep_href_link(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, '', 'SSL'), 'post', 'onSubmit="return check_form();"'); ?>
-      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
+<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
+<?php
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
+  }
+?>
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
+<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
+<?php echo tep_draw_form('checkout_address', tep_href_link(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, '', 'SSL'), 'post', 'onSubmit="return check_form();"') . "\n"; ?>
+<div id="checkout">
 <?php
   if ($process == true) {
 ?>
-      <div class="checkoutErrorHeader"><?php echo TABLE_HEADING_NEW_SHIPPING_ADDRESS_PROBLEM; ?></div>
-      <div class="checkoutErrorContents">
-        <div class="checkoutErrorMessage"><?php echo TEXT_NEW_SHIPPING_ADDRESS_PROBLEM; ?></div>
-      </div>
+<h3><?php echo TABLE_HEADING_NEW_SHIPPING_ADDRESS_PROBLEM; ?></h3>
+<p class="caution"><?php echo TEXT_NEW_SHIPPING_ADDRESS_PROBLEM; ?></p>
 <?php
   }
 
   if ($process == false) {
 ?>
-      <div class="checkoutAddressHeader"><?php echo TABLE_HEADING_SHIPPING_ADDRESS; ?></div>
-      <div class="checkoutAddressConfirmation">
-        <div class="checkoutChooseDestination"><?php echo TEXT_SELECTED_SHIPPING_DESTINATION; ?></div>
-        <div class="checkoutAddressLabel"><?php echo tep_address_label($customer_id, $sendto, true, ' ', '<br>'); ?></div>
-      </div>
+<h3><?php echo TABLE_HEADING_SHIPPING_ADDRESS; ?></h3>
+<p><?php echo TEXT_SELECTED_SHIPPING_DESTINATION; ?></p>
+<p class="addressLabel"><?php echo tep_address_label($customer_id, $sendto, true, ' ', '<br />'); ?></p>
 <?php
     $addresses_count_query = tep_db_query("select count(*) as total from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . $customer_id . "' and address_book_id != '" . $sendto . "'");
     $addresses_count = tep_db_fetch_array($addresses_count_query);
 
     if ($addresses_count['total'] > 0) {
 ?>
-      <div class="checkoutChooseModuleHeader"><?php echo TABLE_HEADING_ADDRESS_BOOK_ENTRIES; ?></div>
-      <table class="checkoutModuleTable">
-      <thead>
-        <tr>
-          <th colspan="2"><?php echo TEXT_SELECT_OTHER_SHIPPING_DESTINATION; ?></th>
-        </tr>
-      </thead>
-      <tbody>
+<h3><?php echo TABLE_HEADING_ADDRESS_BOOK_ENTRIES; ?></h3>
+<p><?php echo TEXT_SELECT_OTHER_SHIPPING_DESTINATION; ?></p>
+<table class="moduleTable" border="0">
 <?php
       $radio_buttons = 0;
 
@@ -418,68 +429,58 @@ function check_form() {
       while ($addresses = tep_db_fetch_array($addresses_query)) {
         $format_id = tep_get_address_format_id($addresses['country_id']);
        if ($addresses['address_book_id'] == $sendto) {
-          echo '        <tr id="defaultSelected" class="checkoutModuleRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
+          echo '<tr id="defaultSelected" class="checkoutModuleRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
         } else {
-          echo '        <tr class="checkoutModuleRow" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
+          echo '<tr class="checkoutModuleRow" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="selectRowEffect(this, ' . $radio_buttons . ')">' . "\n";
         }
 ?>
-          <td class="checkoutModuleTitle"><?php echo tep_output_string_protected(tep_get_fullname($addresses['firstname'],$addresses['lastname'])); ?></td>
-          <td class="checkoutModuleSelect"><?php echo tep_draw_radio_field('address', $addresses['address_book_id'], ($addresses['address_book_id'] == $sendto)); ?></td>
-        </tr>
-        <tr>
-           <td class="checkoutModuleMethod"><?php echo tep_address_format($format_id, $addresses, true, ' ', ', '); ?></td>
-          <td class="checkoutModuleSelect"></td>
-        </tr>
+<th class="select"><?php echo tep_draw_radio_field('address', $addresses['address_book_id'], ($addresses['address_book_id'] == $sendto)); ?></th>
+<th class="title"><?php echo tep_output_string_protected(tep_get_fullname($addresses['firstname'],$addresses['lastname'])); ?></th>
+</tr>
+<tr>
+<td class="select">&nbsp;</td>
+<td class="method"><?php echo tep_address_format($format_id, $addresses, true, ' ', ', '); ?></td>
+</tr>
 <?php
         $radio_buttons++;
       }
 ?>
-      </tbody>
-      </table>
+</table>
 <?php
     }
   }
   if ($addresses_count['total'] < MAX_ADDRESS_BOOK_ENTRIES) {
 ?>
-      <div class="checkoutNewAddressHeader"><?php echo TABLE_HEADING_NEW_SHIPPING_ADDRESS; ?></div>
-      <div class="checkoutNewAddress">
-        <div class="checkoutNewAddressText"><?php echo TEXT_CREATE_NEW_SHIPPING_ADDRESS; ?></div>
+<h3><?php echo TABLE_HEADING_NEW_SHIPPING_ADDRESS; ?></h3>
+<p><?php echo TEXT_CREATE_NEW_SHIPPING_ADDRESS; ?></p>
 <?php require(DIR_WS_MODULES . 'checkout_new_address.php'); ?>
-      </div>
 <?php
   }
-
   if ($process == true) {
 ?>
-      <table>
-        <tr class="buttonLine">
-          <td class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, '', 'SSL') . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></td>
-          <td class="buttonRight"><?php echo tep_draw_hidden_field('action', 'submit') . tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></td>
-        </tr>
-      </table>
+<div class="buttonLine">
+<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_SHIPPING_ADDRESS_SHORT, '', 'SSL') . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
+<p class="buttonRight"><?php echo tep_draw_hidden_field('action', 'submit') . tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
+</div>
 <?php
   } else {
 ?>
-      <table>
-        <tr class="buttonLine">
-          <td class="buttonRight"><?php echo tep_draw_hidden_field('action', 'submit') . tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></td>
-        </tr>
-      </table>
+<div class="buttonLine">
+<p class="buttonRight"><?php echo tep_draw_hidden_field('action', 'submit') . tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
+</div>
 <?php
   }
 ?>
-    </form></td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
-<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-<!-- footer //-->
-<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
 </div>
+</form>
+</div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
