@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: currencies.php,v 1.1.1.1 2005/06/30 05:04:14 ryu Exp $
+  $Id: currencies.php,v 1.2 2006/07/16 05:09:34 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -15,7 +15,7 @@
 
   if (isset($currencies) && is_object($currencies)) {
 ?>
-<!-- currencies //-->
+<!-- currenciesBox -->
 <?php
     $cssid = 'currenciesBox';
     $infobox_header = BOX_HEADING_CURRENCIES;
@@ -40,7 +40,7 @@
 
     new infoBox($cssid, $infobox_contents, $infobox_header);
 ?>
-<!-- currencies_eof //-->
+<!-- /currenciesBox -->
 <?php
   }
 ?>
