@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: tell_a_friend.php,v 1.1.1.1 2005/06/30 05:04:14 ryu Exp $
+  $Id: tell_a_friend.php,v 1.2 2006/07/16 05:09:34 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -13,15 +13,15 @@
   http://www.koshoten.net/
 */
 ?>
-<!-- tell_a_friend //-->
+<!-- tellAFriendBox -->
 <?php
   $cssid = 'tellAFriendBox';
   $infobox_header = BOX_HEADING_TELL_A_FRIEND;
 
   $infobox_contents = array();
   $infobox_contents[] = array('form' => tep_draw_form('tell_a_friend', tep_href_link(FILENAME_TELL_A_FRIEND, '', 'NONSSL', false), 'get'),
-                               'text' => tep_draw_input_field('send_to', '', 'size="10" class="inputText"') . '&nbsp;' . tep_image_submit('button_tell_a_friend.gif', BOX_HEADING_TELL_A_FRIEND) . tep_draw_hidden_field('products_id', $HTTP_GET_VARS['products_id']) . tep_hide_session_id() . '<br>' . BOX_TELL_A_FRIEND_TEXT);
+                               'text' => tep_draw_input_field('send_to', '', 'size="10" class="inputText"') . '&nbsp;' . tep_image_submit('button_tell_a_friend.gif', BOX_HEADING_TELL_A_FRIEND) . tep_draw_hidden_field('products_id', $HTTP_GET_VARS['products_id']) . tep_hide_session_id() . '<br />' . BOX_TELL_A_FRIEND_TEXT);
 
   new infoBox($cssid, $infobox_contents, $infobox_header);
 ?>
-<!-- tell_a_friend_eof //-->
+<!-- /tellAFriendBox -->
