@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: email.php,v 1.2 2005/10/18 09:31:42 ryu Exp $
+  $Id: email.php,v 1.3 2006/01/29 14:49:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -480,13 +480,13 @@
       }
 
       if ($subject != '') {
-        $subject = mb_encode_mimeheader(mb_convert_kana($subject, "KV"), 'ISO-2022-JP');
+        $subject = mb_encode_mimeheader(mb_convert_kana($subject, "KV"), 'ISO-2022-JP', "B", $this->lf);
       }
       $to    = ($to_name != '')
-          ? ('"' . mb_encode_mimeheader(mb_convert_kana($to_name, "KV"), 'ISO-2022-JP') . '" <' . $to_addr . '>')
+          ? ('"' . mb_encode_mimeheader(mb_convert_kana($to_name, "KV"), 'ISO-2022-JP', "B", $this->lf) . '" <' . $to_addr . '>')
           : $to_addr;
       $from  = ($from_name != '')
-          ? ('"' . mb_encode_mimeheader(mb_convert_kana($from_name, "KV"), 'ISO-2022-JP')  . '" <' . $from_addr. '>')
+          ? ('"' . mb_encode_mimeheader(mb_convert_kana($from_name, "KV"), 'ISO-2022-JP', "B", $this->lf)  . '" <' . $from_addr. '>')
           : $from_addr;
 
       if (is_string($headers)) {
