@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: column_right.php,v 1.4 2006/03/23 03:21:10 ryu Exp $
+  $Id: column_right.php,v 1.5 2006/07/16 05:09:34 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -14,7 +14,11 @@
 */
 
   if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
-    echo '    <td id="rightColumn"><div class="sideContents">' . "\n";
+    echo '<div id="rightColumn">' . "\n";
+    // BOX
+    if (KN_CFG_BOX_LOGIN == 1) {
+      require(DIR_WS_BOXES . 'login.php');
+    }
     // BOX
     if (KN_CFG_BOX_SEARCH == 1) {
       require(DIR_WS_BOXES . 'search.php');
@@ -98,14 +102,14 @@
     $si_column_right_query = tep_db_query("select shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_COLUMN_RIGHT'");
     $si_column_right = tep_db_fetch_array($si_column_right_query);
     if (isset($si_column_right['shop_info_value']) && tep_not_null($si_column_right['shop_info_value'])) {
-      echo '<div id="siColumnRight">';
+      echo '<div id="sideColumnRight">';
       if ($si_column_right['allow_tags']) {
         echo $si_column_right['shop_info_value'];
       } else {
         echo nl2br(htmlspecialchars($si_column_right['shop_info_value']));
       }
-      echo '</div>' . "\n";
+      echo "</div>\n";
     }
-    echo '    </div></td>' . "\n";
+    echo "</div>\n";
   }
 ?>
