@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: japanese.php,v 1.3 2006/02/05 11:36:35 ryu Exp $
+  $Id: japanese.php,v 1.6 2006/07/16 05:09:34 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -51,7 +51,7 @@ function tep_date_raw($date, $reverse = false) {
 define('LANGUAGE_CURRENCY', 'JPY');
 
 // Global entries for the <html> tag
-define('HTML_PARAMS','dir="LTR" lang="ja"');
+define('HTML_PARAMS','xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja"');
 
 // charset for web pages and emails
 define('CHARSET', 'EUC-JP');    // Shift_JIS / euc-jp / iso-2022-jp
@@ -65,6 +65,9 @@ define('TEXT_GETA_LOGO', 'GETA');
 define('TEXT_GETA_INFORMATION', '');
 //define('TEXT_GETA_INFORMATION', 'Ϣ۷׻󥸥ʣǣţԣˡפϡȶ(IPA)»ܤŪ󵻽Ѱȡפθ̤Ǥ ');
 
+define('TEXT_NAVISKIP', 'ʥӥФʸ˿ʤߤޤ');
+define('TEXT_NAVISKIPPED', 'ڤʸ');
+
 // header text in includes/header.php
 define('HEADER_TITLE_CREATE_ACCOUNT', 'Ⱥ');
 define('HEADER_TITLE_MY_ACCOUNT', 'Ⱦ');
@@ -132,12 +135,12 @@ define('BOX_HEADING_CUSTOMER_ORDERS', 'ʸ');
 
 // best_sellers box text in includes/boxes/best_sellers.php
 define('BOX_HEADING_BESTSELLERS', '٥ȥ顼');
-define('BOX_HEADING_BESTSELLERS_IN', '&nbsp;&nbsp;<br>Υڥȥ顼');
+define('BOX_HEADING_BESTSELLERS_IN', '&nbsp;&nbsp;<br />Υڥȥ顼');
 
 // notifications box text in includes/boxes/products_notifications.php
 define('BOX_HEADING_NOTIFICATIONS', 'E-MailǤΤ餻');
-define('BOX_NOTIFICATIONS_NOTIFY', '<b>%s</b>κǿΤ餻!');
-define('BOX_NOTIFICATIONS_NOTIFY_REMOVE', '<b>%s</b>κǿΤ餻ʤ');
+define('BOX_NOTIFICATIONS_NOTIFY', '<strong>%s</strong>κǿΤ餻!');
+define('BOX_NOTIFICATIONS_NOTIFY_REMOVE', '<strong>%s</strong>κǿΤ餻ʤ');
 
 // manufacturer box text
 define('BOX_HEADING_MANUFACTURER_INFO', '᡼');
@@ -161,6 +164,12 @@ define('BOX_INFORMATION_CONTACT', '䤤碌');
 define('BOX_HEADING_TELL_A_FRIEND', 'ͧãΤ餻');
 define('BOX_TELL_A_FRIEND_TEXT', 'ξʤURLͧã˥᡼뤹');
 
+// login box text in includes/boxes/login.php
+define('BOX_HEADING_LOGIN', '');
+define('BOX_LOGIN_EMAIL', 'E-Mailɥ쥹:');
+define('BOX_LOGIN_PASSWORD', 'ѥ:');
+define('BOX_LOGIN_GOTO', '̤');
+
 // checkout procedure text
 define('CHECKOUT_BAR_DELIVERY',    'ˡ');
 define('CHECKOUT_BAR_PAYMENT',     'ʧˡ');
@@ -213,6 +222,12 @@ define('ENTRY_FIRST_NAME_TEXT', '<span class="entryRequired">ɬ</span>');
 define('ENTRY_LAST_NAME', ':');
 define('ENTRY_LAST_NAME_ERROR', '<span class="entryError">ʤƤ ' . ENTRY_LAST_NAME_MIN_LENGTH . ' ʸ</span>');
 define('ENTRY_LAST_NAME_TEXT', '<span class="entryRequired">ɬ</span>');
+define('ENTRY_FIRST_NAME_KANA', '̾ʤʡ:');
+define('ENTRY_FIRST_NAME_KANA_ERROR', '');
+define('ENTRY_FIRST_NAME_KANA_TEXT', '');
+define('ENTRY_LAST_NAME_KANA', 'ʤʡ:');
+define('ENTRY_LAST_NAME_KANA_ERROR', '');
+define('ENTRY_LAST_NAME_KANA_TEXT', '');
 define('ENTRY_DATE_OF_BIRTH', 'ǯ:');
 define('ENTRY_DATE_OF_BIRTH_ERROR', '<span class="entryError">(. 1970/05/21)</span>');
 define('ENTRY_DATE_OF_BIRTH_TEXT', '<small>(. 1970/05/21)</small> <span class="entryRequired">ɬ</span>');
@@ -235,7 +250,7 @@ define('ENTRY_CITY_ERROR', '<span class="entryError">ʤƤ ' . ENTRY_CITY_MIN_LEN
 define('ENTRY_CITY_TEXT', '<span class="entryRequired">ɬ</span>');
 define('ENTRY_STATE', 'ƻܸ:');
 define('ENTRY_STATE_ERROR', '<span class="entryError">ɬ</span>');
-define('ENTRY_STATE_TEXT', '<span class="entryRequired">ɬ</span');
+define('ENTRY_STATE_TEXT', '<span class="entryRequired">ɬ</span>');
 define('ENTRY_COUNTRY', '̾:');
 define('ENTRY_COUNTRY_ERROR', '');
 define('ENTRY_COUNTRY_TEXT', '<span class="entryRequired">ɬ</span>');
@@ -245,10 +260,10 @@ define('ENTRY_TELEPHONE_NUMBER_TEXT', '<span class="entryRequired">ɬ</span>');
 define('ENTRY_FAX_NUMBER', 'եֹ:');
 define('ENTRY_FAX_NUMBER_ERROR', '');
 define('ENTRY_FAX_NUMBER_TEXT', '');
-define('ENTRY_NEWSLETTER', '᡼ޥ:');
+define('ENTRY_NEWSLETTER', 'ŹΤ᡼:');
 define('ENTRY_NEWSLETTER_TEXT', '');
-define('ENTRY_NEWSLETTER_YES', 'ɤ');
-define('ENTRY_NEWSLETTER_NO', 'ɤʤ');
+define('ENTRY_NEWSLETTER_YES', '˾');
+define('ENTRY_NEWSLETTER_NO', '˾ʤ');
 define('ENTRY_NEWSLETTER_ERROR', '');
 define('ENTRY_PASSWORD', 'ѥ:');
 define('ENTRY_PASSWORD_CONFIRMATION', 'ѥɤ:');
@@ -259,11 +274,11 @@ define('PASSWORD_HIDDEN', '********');
 
 // constants for use in tep_prev_next_display function
 define('TEXT_RESULT_PAGE', 'ڡ:');
-define('TEXT_DISPLAY_NUMBER_OF_PRODUCTS', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> 뾦ʤΤ)');
-define('TEXT_DISPLAY_NUMBER_OF_ORDERS', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> ʸΤ)');
-define('TEXT_DISPLAY_NUMBER_OF_REVIEWS', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> ɾΤ)');
-define('TEXT_DISPLAY_NUMBER_OF_PRODUCTS_NEW', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> 뿷徦ʤΤ)');
-define('TEXT_DISPLAY_NUMBER_OF_SPECIALS', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> òʤΤ)');
+define('TEXT_DISPLAY_NUMBER_OF_PRODUCTS', '<strong>%d</strong> - <strong>%d</strong> ܤɽ (<strong>%d</strong> 뾦ʤΤ)');
+define('TEXT_DISPLAY_NUMBER_OF_ORDERS', '<strong>%d</strong> - <strong>%d</strong> ܤɽ (<strong>%d</strong> ʸΤ)');
+define('TEXT_DISPLAY_NUMBER_OF_REVIEWS', '<strong>%d</strong> - <strong>%d</strong> ܤɽ (<strong>%d</strong> ɾΤ)');
+define('TEXT_DISPLAY_NUMBER_OF_PRODUCTS_NEW', '<strong>%d</strong> - <strong>%d</strong> ܤɽ (<strong>%d</strong> 뿷徦ʤΤ)');
+define('TEXT_DISPLAY_NUMBER_OF_SPECIALS', '<strong>%d</strong> - <strong>%d</strong> ܤɽ (<strong>%d</strong> òʤΤ)');
 
 define('PREVNEXT_TITLE_FIRST_PAGE', 'ǽΥڡ');
 define('PREVNEXT_TITLE_PREVIOUS_PAGE', 'ڡ');
@@ -309,9 +324,8 @@ define('ICON_ARROW_RIGHT', 'ɽ'); //more
 define('ICON_CART', 'Ȥ');
 define('ICON_WARNING', 'ٹ');
 
-define('TEXT_GREETING_PERSONAL', 'ä㤤ޤ<span class="greetUser">%s </span> <a href="%s"><u>徦</u></a> ˤʤޤ');
-define('TEXT_GREETING_PERSONAL_RELOGON', '<small>⤷ʤ %s ǤʤСȾϤ <a href="%s"><u></u></a> Ƥ</small>');
-define('TEXT_GREETING_GUEST', '<span class="greetUser">Ȥ</span>ä㤤ޤ <a href="%s"><u></u></a>ޤ Ȥ⡢<a href="%s"><u></u></a>ޤ');
+define('TEXT_GREETING_PERSONAL', 'ä㤤ޤ<span class="greetUser">%s </span> <a href="%s">徦</a> ˤʤޤ');
+define('TEXT_GREETING_GUEST', '<span class="greetUser">Ȥ</span>ä㤤ޤ <a href="%s"></a>ޤ Ȥ⡢<a href="%s"></a>ޤ');
 
 define('TEXT_SORT_PRODUCTS', 'ʤ¤ؤ ');
 define('TEXT_DESCENDINGLY', '߽');
@@ -332,7 +346,7 @@ define('TEXT_REQUIRED', 'ɬ');
 
 define('TEXT_TIME_SPECIFY', 'Ϥ: '); // add for Japanese update
 
-define('ERROR_TEP_MAIL', '<font face="Verdana, Arial" size="2" color="#ff0000"><b><small>顼:</small> ꤵ줿SMTP Ф᡼Ǥޤ php.ini SMTP ǧơɬפнƤ</b></font>');
+define('ERROR_TEP_MAIL', '<span class="caution"><strong>顼:</strong> ꤵ줿SMTP Ф᡼Ǥޤ php.ini SMTP ǧơɬפнƤ');
 define('WARNING_INSTALL_DIRECTORY_EXISTS', 'ٹ: 󥹥ȡ롦ǥ쥯ȥ(/install)¸ߤޤޤǤ: ' . dirname($HTTP_SERVER_VARS['SCRIPT_FILENAME']) . '/install. ǥ쥯ȥϥƥδޤΤǺƤ');
 define('WARNING_CONFIG_FILE_WRITEABLE', 'ٹ: ե(/includes/configure.php)˽񤭹߸¤ꤵ줿ޤޤǤ: ' . dirname($HTTP_SERVER_VARS['SCRIPT_FILENAME']) . '/includes/configure.php. եΥ桼¤ѹƤ');
 define('WARNING_SESSION_DIRECTORY_NON_EXISTENT', 'ٹ: å󡦥ǥ쥯ȥ꤬¸ߤޤ: ' . tep_session_save_path() . '. åѤ뤿˥ǥ쥯ȥƤ');
@@ -362,7 +376,7 @@ define('MODULE_PAYMENT_COD_TEXT_EMAIL_FOOTER', '');
   Please leave this comment intact together with the
   following copyright announcement.
 */
-define('FOOTER_TEXT_BODY', 'Copyright &copy; 2004 <a href="http://www.koshoten.net/" target="_blank">Koshoten.net2</a><br>Powered by <a href="http://www.oscommerce.com/" target="_blank">osCommerce</a>');
+define('FOOTER_TEXT_BODY', 'Copyright &copy; 2004 <a href="http://www.koshoten.net/" target="_blank">Koshoten.net2</a><br />Powered by <a href="http://www.oscommerce.com/" target="_blank">osCommerce</a>');
 
 define('EMAIL_SIGNATURE', '');
 ?>
\ No newline at end of file
