@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: advanced_search.php,v 1.2 2005/09/24 12:27:42 ryu Exp $
+  $Id: advanced_search.php,v 1.3 2006/07/16 05:09:35 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -40,8 +40,8 @@ define('TEXT_ALL_CATEGORIES', 'ƥ꡼');
 define('TEXT_ALL_MANUFACTURERS', '' . KN_CFG_USE_MANUFACTURERS);
 
 define('HEADING_SEARCH_HELP', 'ܺٸλȤ');
-define('TEXT_SEARCH_HELP', 'ƹǤϡñʸ AND  OR Ƕڤ뤳ȤǤޤ<br><br>㤨С<u>ʳ AND </u>ϤȡξñդʤõޤФơ<u> OR ߧ߷</u>Ϥȡɤ餫ñդʤõޤ<br><br>ĤñǰϤǸȡϤʸΤ˰פΤõޤ<br><br>㤨С<u>" ʳ"</u>ȤƸȡΤޤޤʸդʤõȤǤޤ<br><br>̤ѤơŪȤ߹碌ꤹ뤳ȤǤޤ<br><br>㤨С<u> AND (ʪ OR  OR " ʳ")</u>ȤƸȡ"" + "ʪ"""Τ!" ʳ"Ȥɤդʤõޤ<br><br>ƹܴ֤ϡANDˤʤޤ<br><br>㤨С̾<u>ǭ</u>̾<u></u>Ϥȡ̾"ǭ"դޤ졢̾""դޤ뾦ʤõޤ');
-define('TEXT_CLOSE_WINDOW', '<u>ɥĤ</u> [x]');
+define('TEXT_SEARCH_HELP', 'ƹǤϡñʸ AND  OR Ƕڤ뤳ȤǤޤ<br /><br />㤨С<strong>ʳ AND </strong>ϤȡξñդʤõޤФơ<strong> OR ߧ߷</strong>Ϥȡɤ餫ñդʤõޤ<br /><br />ĤñǰϤǸȡϤʸΤ˰פΤõޤ<br /><br />㤨С<strong>" ʳ"</strong>ȤƸȡΤޤޤʸդʤõȤǤޤ<br /><br />̤ѤơŪȤ߹碌ꤹ뤳ȤǤޤ<br /><br />㤨С<strong> AND (ʪ OR  OR " ʳ")</strong>ȤƸȡ"" + "ʪ"""Τ!" ʳ"Ȥɤդʤõޤ<br /><br />ƹܴ֤ϡANDˤʤޤ<br /><br />㤨С̾<strong>ǭ</strong>̾<strong></strong>Ϥȡ̾"ǭ"դޤ졢̾""դޤ뾦ʤõޤ');
+define('TEXT_CLOSE_WINDOW', 'ɥĤ [x]');
 
 define('JS_AT_LEAST_ONE_INPUT', '* ΥեɤΤ줫ϤƤ:\n    \n    ǡϿ()\n    ǡϿ(λ)\n    ()\n    (ǹ)\n');
 define('JS_INVALID_FROM_DATE', '* Ͽ()ޤ\n');
