@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_process.php,v 1.2 2005/09/24 12:27:42 ryu Exp $
+  $Id: checkout_process.php,v 1.3 2006/02/01 07:11:51 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -36,6 +36,9 @@ define('EMAIL_TEXT_SUBTOTAL', ':');
 define('EMAIL_TEXT_TAX', ':');
 define('EMAIL_TEXT_SHIPPING', ':');
 define('EMAIL_TEXT_TOTAL', '׳:');
+define('EMAIL_TEXT_CUSTOMER', '');
+define('EMAIL_TEXT_CUSTOMER_NAME', '[̾]');
+define('EMAIL_TEXT_CUSTOMER_EMAIL_ADDRESS', '[E-Mailɥ쥹]');
 define('EMAIL_TEXT_DELIVERY_ADDRESS', 'Ϥ');
 define('EMAIL_TEXT_BILLING_ADDRESS', '');
 define('EMAIL_TEXT_PAYMENT_METHOD', 'ʧˡ');
