@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: create_account.php,v 1.1.1.1 2005/06/30 05:04:17 ryu Exp $
+  $Id: create_account.php,v 1.2 2006/07/16 05:09:35 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -15,5 +15,5 @@
 
 define('NAVBAR_TITLE', 'Ȥκ');
 define('HEADING_TITLE', 'Ⱦ');
-define('TEXT_ORIGIN_LOGIN', ': ˥ȤƤϡ<a href="%s"><u>ڡ</u></a>󤷤Ƥ');
+define('TEXT_ORIGIN_LOGIN', ': ˥ȤƤϡ<a href="%s">ڡ</a>󤷤Ƥ');
 ?>
\ No newline at end of file
