@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: nochex.php,v 1.1.1.1 2005/06/30 05:04:18 ryu Exp $
+  $Id: nochex.php,v 1.2 2006/07/16 05:09:36 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -11,5 +11,5 @@
 */
 
   define('MODULE_PAYMENT_NOCHEX_TEXT_TITLE', 'NOCHEX');
-  define('MODULE_PAYMENT_NOCHEX_TEXT_DESCRIPTION', 'NOCHEX<br>GBP̲ߤɬפǤ.');
+  define('MODULE_PAYMENT_NOCHEX_TEXT_DESCRIPTION', 'NOCHEX<br />GBP̲ߤɬפǤ.');
 ?>
\ No newline at end of file
