@@ -1,12 +1,9 @@
 <?php
 /*
-  geta_products.php
-  2004/12/1
-ǽ2005/6/1
+  $Id: geta_products.php,v 1.3 2006/07/16 05:09:36 ryu Exp $
 
-ԡͭ²ҥɥ֥졼
-δʿ
-ryuhei@secondbrain.co.jp
+Koshoten.net2
+http://www.koshoten.net/
 
   Released under the GNU General Public License
 
@@ -18,7 +15,7 @@ ryuhei@secondbrain.co.jp
   //----------------------------------------------------------------------------//
 */
 ?>
-<!-- geta_products //-->
+<!-- getaProducts -->
 <?php
   $results_count = 0;
   $original_products_array = array();
@@ -59,7 +56,18 @@ ryuhei@secondbrain.co.jp
             if ($num_products > 0) {
               $geta_products = tep_db_fetch_array($geta_products_query);
               if ($results_count < KN_CFG_GETA_PRODUCTS_MAX) {
-                $geta_products_text[] = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $geta_products['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $geta_products['products_image'], $geta_products['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a><br><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $geta_products['products_id']) . '">' . $geta_products['products_name'] . '</a><br>' . ((KN_CFG_CONTACT_PRICE != 0) && ($geta_products['products_price'] == KN_CFG_CONTACT_PRICE) ? '' : $currencies->display_price($geta_products['products_price'], tep_get_tax_rate($geta_products['products_tax_class_id'])));
+              	  if ((KN_CFG_CONTACT_PRICE != 0) && ($geta_products['products_price'] == KN_CFG_CONTACT_PRICE)) {
+              	    $geta_products_price = '-';
+              	  } else {
+                  if ($geta_products_special_price = tep_get_products_special_price($geta_products['products_id'])) {
+                    $geta_products_price = '<del>' . $currencies->display_price($geta_products['products_price'], tep_get_tax_rate($geta_products['products_tax_class_id'])) . '</del><br /><span class="specialPrice">' . $currencies->display_price($geta_products_special_price, tep_get_tax_rate($geta_products['products_tax_class_id']));
+                  } else {
+              	      $geta_products_price = $currencies->display_price($geta_products['products_price'], tep_get_tax_rate($geta_products['products_tax_class_id']));
+                  }
+              	  }
+                $geta_products_text[] = '<div><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $geta_products['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $geta_products['products_image'], $geta_products['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></div>\n" .
+                                                '<p><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $geta_products['products_id']) . '">' . $geta_products['products_name'] . "</a></p>\n" .
+                                                '<p class="pPrice">' . $geta_products_price . "</p>\n";
               }
               $results_count++;
             }
@@ -80,8 +88,7 @@ ryuhei@secondbrain.co.jp
     $col = 0;
     $contentbox_contents = array();
     for ($i=0; $i<KN_CFG_GETA_PRODUCTS_MAX; $i++) {
-      $contentbox_contents[$row][$col] = array('params' => 'class="getaProductsData"',
-                                             'text' => $geta_products_text[$i]);
+      $contentbox_contents[$row][$col] = array('text' => $geta_products_text[$i]);
       $col ++;
       if ($col > 2) {
         $col = 0;
@@ -92,4 +99,4 @@ ryuhei@secondbrain.co.jp
     new contentBox($cssid, $contentbox_contents, $contentbox_header);
   }
 ?>
-<!-- geta_products_eof //-->
+<!-- /getaProducts -->
