@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: cod_table.php,v 1.2 2006/01/29 14:49:24 ryu Exp $
+  $Id: cod_table.php,v 1.4 2006/07/16 05:09:36 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -41,7 +41,7 @@
 
       if (is_object($order)) $this->update_status();
 
-      $this->email_footer = MODULE_PAYMENT_COD_TABLE_TEXT_EMAIL_FOOTER;
+      $this->email_footer = MODULE_PAYMENT_COD_TABLE_TEXT_MAILFOOTER;
     }
 
 // class methods
@@ -116,7 +116,7 @@
 
       $s_message = $f_result
         ? (MODULE_PAYMENT_COD_TABLE_TEXT_FEE . '&nbsp;' . $currencies->format($this->n_fee))
-        : ('<font color="#FF0000">' . $this->s_error . '</font>');
+        : ('<span class="caution">' . $this->s_error . '</span>');
 
       $selection = array(
           'id' => $this->code,
@@ -148,7 +148,7 @@
       $this->get_codt_fee_value();  // $GLOBALS['codt_fee'] 
       $s_message = $s_result
         ? (MODULE_PAYMENT_COD_TABLE_TEXT_FEE . '&nbsp;' . $currencies->format($GLOBALS['codt_fee']))
-        : ('<font color="#FF0000">' . $HTTP_POST_VARS['codt_fee_error'] . '</font>');
+        : ('<span class="caution">' . $HTTP_POST_VARS['codt_fee_error'] . '</span>');
 // 2005-02-09 modi -e
 
       $confirmation = array(
@@ -182,9 +182,7 @@
       $this->get_codt_fee_value();  // $GLOBALS['codt_fee'] 
       $s_message = $HTTP_POST_VARS['codt_fee_error']
         ? $HTTP_POST_VARS['codt_fee_error']
-        : sprintf(MODULE_PAYMENT_COD_TABLE_TEXT_MAILFOOTER,
-            $currencies->format($order->info['total']),
-            $currencies->format($GLOBALS['codt_fee']));
+        : MODULE_PAYMENT_COD_TABLE_TEXT_MAILFOOTER;
 
       return tep_draw_hidden_field('codt_message', htmlspecialchars($s_message));
 // 2005-02-09 modi -e
@@ -215,6 +213,7 @@
     }
 
     function install() {
+      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ʧˡ', 'MODULE_PAYMENT_COD_TABLE_TEXT_TITLE', 'ʧ', 'ʧˡ̾', '6', '11' , now())");
       tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('ʧͭˤ', 'MODULE_PAYMENT_COD_TABLE_STATUS', 'True', 'ˤʧդޤ?', '6', '1', 'tep_cfg_select_option(array(\'True\', \'False\'), ',now());");
 
       tep_db_query("insert into " . TABLE_CONFIGURATION .
@@ -223,6 +222,8 @@
       tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_PAYMENT_COD_TABLE_SORT_ORDER', '0', 'ɽǤޤۤɾ̤ɽޤ.', '6', '0' , now())");
       tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Ŭϰ', 'MODULE_PAYMENT_COD_TABLE_ZONE', '0', 'Ŭϰ򤹤ȡ򤷤ϰΤߤѲǽȤʤޤ.', '6', '3', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");
       tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, use_function, date_added) values ('ʸơ', 'MODULE_PAYMENT_COD_TABLE_ORDER_STATUS_ID', '0', 'ꤷơŬѤޤ.', '6', '4', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
+      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ʧˡ', 'MODULE_PAYMENT_COD_TABLE_TEXT_PROCESS', '۶ȼԤʤϤȤˡʤȰդˤ򤪻ʧ', '쥸λʧˡ̤ɽǤ', '6', '12' , now())");
+      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('᡼ؤ', 'MODULE_PAYMENT_COD_TABLE_TEXT_MAILFOOTER', 'ʤˡޤˤ\nãˤʧ', 'ʸǧ᡼ɵʸ̤Ǥ', '6', '13', 'tep_cfg_textarea(', now())");
     }
 
     function remove() {
@@ -231,11 +232,14 @@
 
     function keys() {
       return array(
+          'MODULE_PAYMENT_COD_TABLE_TEXT_TITLE',
           'MODULE_PAYMENT_COD_TABLE_STATUS',
           'MODULE_PAYMENT_COD_TABLE_COST',
           'MODULE_PAYMENT_COD_TABLE_SORT_ORDER',
           'MODULE_PAYMENT_COD_TABLE_ZONE',
-          'MODULE_PAYMENT_COD_TABLE_ORDER_STATUS_ID'
+          'MODULE_PAYMENT_COD_TABLE_ORDER_STATUS_ID',
+          'MODULE_PAYMENT_COD_TABLE_TEXT_PROCESS',
+          'MODULE_PAYMENT_COD_TABLE_TEXT_MAILFOOTER'
       );
     }
 // 2005-02-09 add -s
