@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: yamato.php,v 1.2 2006/01/29 14:49:24 ryu Exp $
+  $Id: yamato.php,v 1.3 2006/06/12 09:31:31 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -181,6 +181,8 @@
     }
 
     function install() {
+      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ˡ', 'MODULE_SHIPPING_YAMATO_TEXT_TITLE', 'ޥȱ͢', 'ˡ̾.', '6', '11', now())");
+      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ӥ', 'MODULE_SHIPPING_YAMATO_TEXT_WAY_NORMAL', '', 'ӥ̾.', '6', '12', now())");
       tep_db_query("insert into " . TABLE_CONFIGURATION .
       " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('ޥؤͭˤ', 'MODULE_SHIPPING_YAMATO_STATUS', 'True', 'ޥؤ󶡤ޤ?', '6', '0', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
 
@@ -205,6 +207,8 @@
 
     function keys() {
       return array(
+        'MODULE_SHIPPING_YAMATO_TEXT_TITLE',
+        'MODULE_SHIPPING_YAMATO_TEXT_WAY_NORMAL',
         'MODULE_SHIPPING_YAMATO_STATUS',
         'MODULE_SHIPPING_YAMATO_HANDLING',
         'MODULE_SHIPPING_YAMATO_FREE_SHIPPING',
