@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: new_products.php,v 1.2 2006/03/23 02:12:26 ryu Exp $
+  $Id: new_products.php,v 1.3 2006/07/16 05:09:36 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -13,7 +13,7 @@
   http://www.koshoten.net/
 */
 ?>
-<!-- new_products //-->
+<!-- newProducts -->
 <?php
   if (KN_CFG_NEW_PRODUCTS_COLUMN_DISPLAY == 'true') {
     if ( (!isset($new_products_category_id)) || ($new_products_category_id == '0') ) {
@@ -35,19 +35,20 @@
       while ($new_products = tep_db_fetch_array($new_products_query)) {
         $new_products_description_query = tep_db_query("select products_name, products_subtitle, products_series_title, products_author, products_published, products_volume, products_publishers from " . TABLE_PRODUCTS_DESCRIPTION . " where products_id = '" . $new_products['products_id'] . "' and language_id = '" . $languages_id . "'");
         $new_products_description = tep_db_fetch_array($new_products_description_query);
-        $new_products_list = '<table class="newProductsTable"><tr>' . "\n";
+        $new_products_list = '<h4><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '"><span class="pName">' . $new_products_description['products_name'] . '</span></a>' . 
+                                               (KN_CFG_USE_SUBTITLE == 'true' ? ' <span class="pSubtitle">' . $new_products_description['products_subtitle'] . '</span>' : '') . 
+                                               (KN_CFG_USE_SERIES_TITLE == 'true' ? ' <span class="pSeriesTitle">' . $new_products_description['products_series_title'] . '</span>' : '') . "</h4>\n";
         if ($new_products['products_image']) {
-          $new_products_list .= '<td width="' . SMALL_IMAGE_WIDTH . '" class="newProductsImage"><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $new_products['products_image'], $new_products_description['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a></td>' . "\n";
+          $new_products_list .= '<p class="pImage"><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $new_products['products_image'], $new_products_description['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a></p>' . "\n";
         }
-        $new_products_list .= '<td class="newProductsProducts"><div class="newProductsName"><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $new_products['products_id']) . '"><span class="pName">' . $new_products_description['products_name'] . '</span></a>' . 
-                                    (KN_CFG_USE_SUBTITLE == 'true' ? ' <span class="pSubtitle">' . $new_products_description['products_subtitle'] . '</span>' : '') . 
-                                    (KN_CFG_USE_SERIES_TITLE == 'true' ? ' <span class="pSeriesTitle">' . $new_products_description['products_series_title'] . '</span>' : '') . '</div>' . 
-                                    '<div class="newProductsDescription01">' . (KN_CFG_USE_AUTHOR == 'true' ? '<span class="pAuthor">' . $new_products_description['products_author'] . '</span> ' : '') . 
-                                    (KN_CFG_USE_PUBLISHERS == 'true' ? '<span class="pPublishers">' . $new_products_description['products_publishers'] . '</span>' : '') . 
-                                    (KN_CFG_USE_VOLUME == 'true' ? '<span class="pVolume">&nbsp;' . $new_products_description['products_volume'] . '</span>' : '') . 
-                                    (KN_CFG_USE_PUBLISHED == 'true' ? '&nbsp;<span class="pPublished">' . $new_products_description['products_published'] . '</span>' : '') . '</div></td>' . "\n" . 
-                                    '<td class="newProductsPrice"><span class="pPrice">' .  ((KN_CFG_CONTACT_PRICE != 0) && ($new_products['products_price'] == KN_CFG_CONTACT_PRICE) ? '' : $currencies->display_price($new_products['products_price'], tep_get_tax_rate($new_products['products_tax_class_id']))) . '</span></td>' . "\n";
-        $new_products_list .= '</tr></table>' . "\n";
+        $new_products_list .= "<ul>\n" . 
+                                    ((KN_CFG_USE_AUTHOR == 'true') && ($new_products_description['products_author']) ? '<li class="pAuthor">' . $new_products_description['products_author'] . "</li>\n" : '') . 
+                                    ((KN_CFG_USE_PUBLISHERS == 'true') && ($new_products_description['products_publishers']) ? '<li class="pPublishers">' . $new_products_description['products_publishers'] . "</li>\n" : '') . 
+                                    ((KN_CFG_USE_VOLUME == 'true') && ($new_products_description['products_volume']) ? '<li class="pVolume">' . $new_products_description['products_volume'] . "</li>\n" : '') . 
+                                    ((KN_CFG_USE_PUBLISHED == 'true') && ($new_products_description['products_published']) ? '<li class="pPublished">' . $new_products_description['products_published'] . "</li>\n" : '') .
+                                    '<li class="pDescription">' . $new_products_description['products_description'] . "</li>\n" . 
+                                    "</ul>\n" .
+                                    '<p class="pPrice">' .  ((KN_CFG_CONTACT_PRICE != 0) && ($new_products['products_price'] == KN_CFG_CONTACT_PRICE) ? '' : $currencies->display_price($new_products['products_price'], tep_get_tax_rate($new_products['products_tax_class_id']))) . "</p>\n";
         $contentbox_contents[$row][$col] = array('params' => 'width="' . $width . '"',
                                                            'text' => $new_products_list);
         $col ++;
@@ -60,4 +61,4 @@
     }
   }
 ?>
-<!-- new_products_eof //-->
+<!-- /newProducts -->
