@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: ot_total.php,v 1.2 2006/01/29 14:49:24 ryu Exp $
+  $Id: ot_total.php,v 1.3 2006/07/16 05:09:37 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -46,7 +46,7 @@
       }
 
       $this->output[] = array('title' => $this->title . ':',
-                              'text' => '<b>' . $currencies->format($total, true, $order->info['currency'], $order->info['currency_value']) . '</b>',
+                              'text' => '<strong>' . $currencies->format($total, true, $order->info['currency'], $order->info['currency_value']) . '</strong>',
                               'value' => $total);
     }
 
