@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: cod_table.php,v 1.2 2006/01/29 14:49:24 ryu Exp $
+  $Id: cod_table.php,v 1.3 2006/07/16 05:09:37 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -110,7 +110,7 @@
 
       $s_message = $f_result
         ? (MODULE_PAYMENT_COD_TABLE_TEXT_FEE . '&nbsp;' . $currencies->format($this->n_fee))
-        : ('<font color="#FF0000">' . $this->s_error . '</font>');
+        : ('<span class="caution">' . $this->s_error . '</span>');
 
       $selection = array(
           'id' => $this->code,
@@ -142,7 +142,7 @@
       $this->get_codt_fee_value();  // $GLOBALS['codt_fee'] 
       $s_message = $s_result
         ? (MODULE_PAYMENT_COD_TABLE_TEXT_FEE . '&nbsp;' . $currencies->format($GLOBALS['codt_fee']))
-        : ('<font color="#FF0000">' . $HTTP_POST_VARS['codt_fee_error'] . '</font>');
+        : ('<span class="caution">' . $HTTP_POST_VARS['codt_fee_error'] . '</span>');
 // 2005-02-09 modi -e
 
       $confirmation = array(
