@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: product_listing.php,v 1.4 2006/03/23 02:12:26 ryu Exp $
+  $Id: product_listing.php,v 1.6 2006/07/16 05:09:36 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -13,7 +13,7 @@
   http://www.koshoten.net/
 */
 ?>
-<div id="productsList">
+<!-- productsList -->
 <?php
   $listing_numrows_sql = $listing_sql;
   $listing_split = new splitPageResults($HTTP_GET_VARS['page'], MAX_DISPLAY_SEARCH_RESULTS, $listing_sql, $listing_numrows);
@@ -26,12 +26,10 @@
 
   if ( ($listing_numrows > 0) && ( (PREV_NEXT_BAR_LOCATION == '1') || (PREV_NEXT_BAR_LOCATION == '3') ) ) {
 ?>
-  <table class="listHeader">
-    <tr>
-      <td class="listCount"><?php echo $listing_split->display_count($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_PRODUCTS); ?></td>
-      <td class="listPrevNext"><?php echo TEXT_RESULT_PAGE; ?> <?php echo $listing_split->display_links($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></td>
-    </tr>
-  </table>
+<div class="listLink">
+<p class="listCount"><?php echo $listing_split->display_count($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_PRODUCTS); ?></p>
+<p class="listPrevNext"><?php echo TEXT_RESULT_PAGE; ?> <?php echo $listing_split->display_links($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></p>
+</div>
 <?php
   }
 ?>
@@ -43,67 +41,67 @@
     switch ($column_list[$col]) {
       case 'PRODUCT_LIST_MODEL':
         $lc_text = TABLE_HEADING_MODEL;
-        $lc_param = 'productListModel';
+        $lc_param = 'pModel';
         break;
       case 'PRODUCT_LIST_NAME':
         $lc_text = TABLE_HEADING_PRODUCTS;
-        $lc_param = 'productListName';
+        $lc_param = 'pName';
         break;
       case 'PRODUCT_LIST_SUBTITLE':
         $lc_text = TABLE_HEADING_SUBTITLE;
-        $lc_param = 'productListSubtitle';
+        $lc_param = 'pSubtitle';
         break;
       case 'PRODUCT_LIST_SERIES_TITLE':
         $lc_text = TABLE_HEADING_SERIES_TITLE;
-        $lc_param = 'productListSeriesTitle';
+        $lc_param = 'pSeriesTitle';
         break;
       case 'PRODUCT_LIST_AUTHOR':
         $lc_text = TABLE_HEADING_AUTHOR;
-        $lc_param = 'productListAuthor';
+        $lc_param = 'pAuthor';
         break;
       case 'PRODUCT_LIST_PUBLISHED':
         $lc_text = TABLE_HEADING_PUBLISHED;
-        $lc_param = 'productListPublished';
+        $lc_param = 'pPublished';
         break;
       case 'PRODUCT_LIST_VOLUME':
         $lc_text = TABLE_HEADING_VOLUME;
-        $lc_param = 'productListVolume';
+        $lc_param = 'pVolume';
         break;
       case 'PRODUCT_LIST_ISBN':
         $lc_text = TABLE_HEADING_ISBN;
-        $lc_param = 'productListIsbn';
+        $lc_param = 'pIsbn';
         break;
       case 'PRODUCT_LIST_DESCRIPTION':
         $lc_text = TABLE_HEADING_DESCRIPTION;
-        $lc_param = 'productListDescription';
+        $lc_param = 'pDescription';
         break;
       case 'PRODUCT_LIST_PUBLISHERS':
         $lc_text = TABLE_HEADING_PUBLISHERS;
-        $lc_param = 'productListPublishers';
+        $lc_param = 'pPublishers';
         break;
       case 'PRODUCT_LIST_PRICE':
         $lc_text = TABLE_HEADING_PRICE;
-        $lc_param = 'productListPrice';
+        $lc_param = 'pPrice';
         break;
       case 'PRODUCT_LIST_QUANTITY':
         $lc_text = TABLE_HEADING_QUANTITY;
-        $lc_param = 'productListQuantity';
+        $lc_param = 'pQuantity';
         break;
       case 'PRODUCT_LIST_WEIGHT':
         $lc_text = TABLE_HEADING_WEIGHT;
-        $lc_param = 'productListWeight';
+        $lc_param = 'pWeight';
         break;
       case 'PRODUCT_LIST_IMAGE':
         $lc_text = TABLE_HEADING_IMAGE;
-        $lc_param = 'productListImage';
+        $lc_param = 'pImage';
         break;
       case 'PRODUCT_LIST_BUY_NOW':
         if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
           $lc_text = '';
-          $lc_param = 'productListBuyNow';
+          $lc_param = 'pBuyNow';
         } else {
           $lc_text = TABLE_HEADING_BUY_NOW;
-          $lc_param = 'productListBuyNow';
+          $lc_param = 'pBuyNow';
         }
         break;
     }
@@ -139,11 +137,11 @@
 
         switch ($column_list[$col]) {
           case 'PRODUCT_LIST_MODEL':
-            $lc_param = 'productListModel';
+            $lc_param = 'pModel';
             $lc_text = $listing['products_model'];
             break;
           case 'PRODUCT_LIST_NAME':
-            $lc_param = 'productListName';
+            $lc_param = 'pName';
             if (isset($HTTP_GET_VARS['manufacturers_id']) && $HTTP_GET_VARS['manufacturers_id']) {
               $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'manufacturers_id=' . $HTTP_GET_VARS['manufacturers_id'] . '&products_id=' . $listing['products_id']) . '">' . $listing['products_name'] . '</a>';
             } else {
@@ -151,35 +149,35 @@
             }
             break;
           case 'PRODUCT_LIST_SUBTITLE':
-            $lc_param = 'productListSubtitle';
+            $lc_param = 'pSubtitle';
             $lc_text = $listing['products_subtitle'];
             break;
           case 'PRODUCT_LIST_SERIES_TITLE':
-            $lc_param = 'productListSeriesTitle';
+            $lc_param = 'pSeriesTitle';
             $lc_text = $listing['products_series_title'];
             break;
           case 'PRODUCT_LIST_AUTHOR':
-            $lc_param = 'productListAuthor';
+            $lc_param = 'pAuthor';
             $lc_text = $listing['products_author'];
             break;
           case 'PRODUCT_LIST_PUBLISHED':
-            $lc_param = 'productListPublished';
+            $lc_param = 'pPublished';
             $lc_text = $listing['products_published'];
             break;
           case 'PRODUCT_LIST_VOLUME':
-            $lc_param = 'productListVolume';
+            $lc_param = 'pVolume';
             $lc_text = $listing['products_volume'];
             break;
           case 'PRODUCT_LIST_ISBN':
-            $lc_param = 'productListIsbn';
+            $lc_param = 'pIsbn';
             $lc_text = $listing['products_isbn'];
             break;
           case 'PRODUCT_LIST_PUBLISHERS':
-            $lc_param = 'productListPublishers';
+            $lc_param = 'pPublishers';
             $lc_text = $listing['products_publishers'];
             break;
           case 'PRODUCT_LIST_DESCRIPTION':
-            $lc_param = 'productListDescription';
+            $lc_param = 'pDescription';
             if (KN_CFG_PRODUCT_LIST_WITHIN_DESCRIPTION == 'true') {
               $lc_text = '';
               if ((KN_CFG_USE_SUBTITLE == 'true') && ($listing['products_subtitle'])) {
@@ -203,9 +201,9 @@
             }
             break;
           case 'PRODUCT_LIST_PRICE':
-            $lc_param = 'productListPrice';
+            $lc_param = 'pPrice';
             if (tep_not_null($listing['specials_new_products_price'])) {
-              $lc_text = '<s>' .  $currencies->display_price($listing['products_price'], tep_get_tax_rate($listing['products_tax_class_id'])) . '</s>&nbsp;&nbsp;<span class="productSpecialPrice">' . $currencies->display_price($listing['specials_new_products_price'], tep_get_tax_rate($listing['products_tax_class_id'])) . '</span>';
+              $lc_text = '<del>' .  $currencies->display_price($listing['products_price'], tep_get_tax_rate($listing['products_tax_class_id'])) . '</del>&nbsp;&nbsp;<span class="specialPrice">' . $currencies->display_price($listing['specials_new_products_price'], tep_get_tax_rate($listing['products_tax_class_id'])) . '</span>';
             } else {
               if ((KN_CFG_CONTACT_PRICE != 0) && ($listing['products_price'] == KN_CFG_CONTACT_PRICE)) {
                 $lc_text = '-';
@@ -215,15 +213,15 @@
             }
             break;
           case 'PRODUCT_LIST_QUANTITY':
-            $lc_param = 'productListQuantity';
+            $lc_param = 'pQuantity';
             $lc_text = $listing['products_quantity'];
             break;
           case 'PRODUCT_LIST_WEIGHT':
-            $lc_param = 'productListWeight';
+            $lc_param = 'pWeight';
             $lc_text = $listing['products_weight'];
             break;
           case 'PRODUCT_LIST_IMAGE':
-            $lc_param = 'productListImage';
+            $lc_param = 'pImage';
             if (isset($HTTP_GET_VARS['manufacturers_id']) && $HTTP_GET_VARS['manufacturers_id']) {
               $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'manufacturers_id=' . $HTTP_GET_VARS['manufacturers_id'] . '&products_id=' . $listing['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $listing['products_image'], $listing['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a>';
             } else {
@@ -231,7 +229,7 @@
             }
             break;
           case 'PRODUCT_LIST_BUY_NOW':
-            $lc_param = 'productListBuyNow';
+            $lc_param = 'pBuyNow';
             if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
               if ((KN_CFG_CONTACT_PRICE != 0) && ($listing['products_price'] == KN_CFG_CONTACT_PRICE)) {
                 if (defined("KN_CFG_CONTACT_BY_EMAIL") && (KN_CFG_CONTACT_BY_EMAIL == 'false')) {
@@ -249,7 +247,7 @@
               }
             } else {
               if ((KN_CFG_CONTACT_PRICE != 0) && ($listing['products_price'] == KN_CFG_CONTACT_PRICE)) {
-                if (KN_CFG_CONTACT_PRICE_BY_EMAIL == 'true') {
+                if (KN_CFG_CONTACT_BY_EMAIL == 'true') {
                   $sjis_p_name = mb_convert_encoding($listing['products_name'], "SJIS", "EUC-JP");
                   $sjis_p_email_subject = mb_convert_encoding(KN_CFG_CONTACT_PRICE_EMAIL_SUBJECT, "SJIS", "EUC-JP");
                   $sjis_p_email_body = mb_convert_encoding(KN_CFG_CONTACT_PRICE_EMAIL_BODY, "SJIS", "EUC-JP");
@@ -278,19 +276,18 @@
     new listingBox($list_box_contents, true, true);
   } else {
 ?>
-  <div class="noData"><?php echo (!empty($HTTP_GET_VARS['manufacturers_id']) ? TEXT_NO_PRODUCTS2 : TEXT_NO_PRODUCTS); ?></div>
+  <p class="noData"><?php echo (!empty($HTTP_GET_VARS['manufacturers_id']) ? TEXT_NO_PRODUCTS2 : TEXT_NO_PRODUCTS); ?></p>
 <?php
   }
 
   if ( ($listing_numrows > 0) && ((PREV_NEXT_BAR_LOCATION == '2') || (PREV_NEXT_BAR_LOCATION == '3')) ) {
 ?>
-  <table class="listFooter">
-    <tr>
-      <td class="listCount"><?php echo $listing_split->display_count($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_PRODUCTS); ?></td>
-      <td class="listPrevNext"><?php echo TEXT_RESULT_PAGE; ?> <?php echo $listing_split->display_links($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></td>
-    </tr>
-  </table>
+<div class="listLink">
+<p class="listCount"><?php echo $listing_split->display_count($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_PRODUCTS); ?></p>
+<p class="listPrevNext"><?php echo TEXT_RESULT_PAGE; ?> <?php echo $listing_split->display_links($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></p>
+</div>
 <?php
   }
 ?>
 </div>
+<!-- /productsList -->
