@@ -1,17 +1,19 @@
 <?php
 /*
-  recommendation.php
-  2004/12/1
-ǽ2006/2/13
+  $Id: recommendation.php,v 1.3 2006/07/16 05:09:36 ryu Exp $
 
-ԡͭ²ҥɥ֥졼
-δʿ
-ryuhei@secondbrain.co.jp
+  osCommerce, Open Source E-Commerce Solutions
+  http://www.oscommerce.com
+
+  Copyright (c) 2003 osCommerce
 
   Released under the GNU General Public License
+  
+  modified for Koshoten.net2
+  http://www.koshoten.net/
 */
 ?>
-<!-- recommendation //-->
+<!-- recommendation -->
 <?php
 
   if (KN_CFG_RECOMMENDATION_COLUMN_DISPLAY == 'true') {
@@ -31,21 +33,21 @@ ryuhei@secondbrain.co.jp
       $width = (int)(100 / KN_CFG_MAX_DISPLAY_RECOMMENDATION_PER_ROW) . '%';
       $contentbox_contents = array();
       while ($recommended = tep_db_fetch_array($recommended_query)) {
-        $recommended_products_list = '<table class="recommendationTable"><tr>' . "\n";
-        if ($recommended['products_image']) {
-        	$recommended_products_list .= '<td width="' . SMALL_IMAGE_WIDTH . '" class="recommendationImage"><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $recommended['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $recommended['products_image'], $recommended['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a></td>' . "\n";
-        }
-        $recommended_products_list .= '<td class="recommendationProducts"><div class="recommendationName"><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $recommended['products_id']) . '"><span class="pName">' . $recommended['products_name'] . '</span></a>' . 
+        $recommended_products_list = '<h4><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $recommended['products_id']) . '"><span class="pName">' . $recommended['products_name'] . '</span></a>' . 
                                                (KN_CFG_USE_SUBTITLE == 'true' ? ' <span class="pSubtitle">' . $recommended['products_subtitle'] . '</span>' : '') . 
-                                               (KN_CFG_USE_SERIES_TITLE == 'true' ? ' <span class="pSeriesTitle">' . $recommended['products_series_title'] . '</span>' : '') . '</div>' . 
-                                               '<div class="recommendationDescription01">' . (KN_CFG_USE_AUTHOR == 'true' ? '<span class="pAuthor">' . $recommended['products_author'] . '</span> ' : '') . 
-                                               (KN_CFG_USE_PUBLISHERS == 'true' ? '<span class="pPublishers">' . $recommended['products_publishers'] . '</span> ' : '') . 
-                                               (KN_CFG_USE_VOLUME == 'true' ? '<span class="pVolume">' . $recommended['products_volume'] . '</span> ' : '') . 
-                                               (KN_CFG_USE_PUBLISHED == 'true' ? '<span class="pPublished">' . $recommended['products_published'] . '</span> ' : '') . 
-                                               '<span class="pDescription">' . $recommended['products_description'] . '</span></div>' . 
-                                               ((KN_CFG_USE_DESCRIPTION2 == 'true') && (KN_CFG_RECOMMENDATION_DESCRIPTION2_DISPLAY == 'true') ? '<div class="recommendationDescription02">' . nl2br($recommended['products_description2']) . '</div>' : '') . "</td>\n" . 
-                                               '<td class="recommendationPrice"><span class="pPrice">' .  ((KN_CFG_CONTACT_PRICE != 0) && ($recommended['products_price'] == KN_CFG_CONTACT_PRICE) ? '' : $currencies->display_price($recommended['products_price'], tep_get_tax_rate($recommended['products_tax_class_id']))) . '</span></td>' . "\n";
-        $recommended_products_list .= '</tr></table>' . "\n";
+                                               (KN_CFG_USE_SERIES_TITLE == 'true' ? ' <span class="pSeriesTitle">' . $recommended['products_series_title'] . '</span>' : '') . "</h4>\n";
+        if ($recommended['products_image']) {
+        	$recommended_products_list .= '<p class="pImage"><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $recommended['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $recommended['products_image'], $recommended['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a></p>' . "\n";
+        }
+        $recommended_products_list .= "<ul>\n" .
+                                               ((KN_CFG_USE_AUTHOR == 'true') && ($recommended['products_author']) ? '<li class="pAuthor">' . $recommended['products_author'] . "</li>\n" : '') . 
+                                               ((KN_CFG_USE_PUBLISHERS == 'true') && ($recommended['products_publishers']) ? '<li class="pPublishers">' . $recommended['products_publishers'] . "</li>\n" : '') . 
+                                               ((KN_CFG_USE_VOLUME == 'true') && ($recommended['products_volume']) ? '<li class="pVolume">' . $recommended['products_volume'] . "</li>\n" : '') . 
+                                               ((KN_CFG_USE_PUBLISHED == 'true') && ($recommended['products_published']) ? '<li class="pPublished">' . $recommended['products_published'] . "</li>\n" : '') . 
+                                               '<li class="pDescription">' . $recommended['products_description'] . "</li>\n" . 
+                                               "</ul>\n" .
+                                               '<p class="pPrice">' . ((KN_CFG_CONTACT_PRICE != 0) && ($recommended['products_price'] == KN_CFG_CONTACT_PRICE) ? KN_CFG_CONTACT_PRICE_TEXT : $currencies->display_price($recommended['products_price'], tep_get_tax_rate($recommended['products_tax_class_id']))) . "</p>\n" . 
+                                               ((KN_CFG_USE_DESCRIPTION2 == 'true') && (KN_CFG_RECOMMENDATION_DESCRIPTION2_DISPLAY == 'true') ? '<p class="pDescription2">' . nl2br($recommended['products_description2']) . "</p>\n" : '');
         $contentbox_contents[$row][$col] = array('params' => 'width="' . $width . '"',
                                                          'text' => $recommended_products_list);
         $col ++;
@@ -59,4 +61,4 @@ ryuhei@secondbrain.co.jp
     }
   }
 ?>
-<!-- recommendation_eof //-->
+<!-- /recommendation -->
