@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: yuupack.php,v 1.2 2006/01/29 14:49:24 ryu Exp $
+  $Id: yuupack.php,v 1.3 2006/07/16 05:09:37 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -184,7 +184,7 @@
       tep_db_query("insert into " . TABLE_CONFIGURATION .
       " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('椦ѥåͭˤ', 'MODULE_SHIPPING_YUUPACK_STATUS', 'True', '̾͹ʪ(椦ѥå)󶡤ޤ?', '6', '0', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
 
-      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('η׻ɽ', 'MODULE_SHIPPING_YUUPACK_TABLE', '3:60,7:80,10:100,15:120,18:140,22:160,30:170', '̤ޤѤ˴Ť.<br>(:): 3:60,7:80,10:100,15:120,18:140,22:160,30:170<br>(:): 7:60,18:80,30:100,60:120,90:140,140:160,160:170', '6', '1', now())");
+      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('η׻ɽ', 'MODULE_SHIPPING_YUUPACK_TABLE', '3:60,7:80,10:100,15:120,18:140,22:160,30:170', '̤ޤѤ˴Ť.<br />(:): 3:60,7:80,10:100,15:120,18:140,22:160,30:170<br />(:): 7:60,18:80,30:100,60:120,90:140,140:160,160:170', '6', '1', now())");
 
       tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('׻ɽδ', 'MODULE_SHIPPING_YUUPACK_MODE', 'weight', '(weight)ޤ(volume)Τɤ׻ɽδȤ뤫Ǥ. weight(kg)volume(åȥ)ʤνϤƤ.', '6', '2', 'tep_cfg_select_option(array(\'weight\', \'volume\'), ', now())");
 
