@@ -33,55 +33,82 @@ ryuhei@secondbrain.co.jp
 
   require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_DEFAULT);
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>"> 
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
+<meta name="description" content="<?php echo KN_CFG_META_DESCRIPTION; ?>" />
+<meta name="keywords" content="<?php echo KN_CFG_META_KEYWORDS; ?>" />
 <title><?php echo TITLE; ?></title>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_DEFAULT, 0, strrpos(FILENAME_DEFAULT, '.'));?>.css">
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_DEFAULT, 0, strrpos(FILENAME_DEFAULT, '.'));?>.css" media="screen,print" />
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+<!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-<!-- body //-->
-<table id="contents">
-  <tr>
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents">
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
+<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
+<?php
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
+  }
+?>
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
 <?php
   if ($category_depth == 'nested') {
-    // ƥ꡼ڡ
+// ƥ꡼ڡ
     $category_query = tep_db_query("select cd.categories_name, cd.categories_description, c.categories_image from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.categories_id = '" . $current_category_id . "' and cd.categories_id = '" . $current_category_id . "' and cd.language_id = '" . $languages_id . "'");
     $category = tep_db_fetch_array($category_query);
 ?>
-      <h1 class="pageHeading"><?php echo $category['categories_name']; ?></h1>
+<h2 class="pageHeading"><?php echo $category['categories_name']; ?></h2>
+<div id="common">
 <?php
     if ($category['categories_image']) {
-      echo '      <div class="pageHeadingImage">' .  tep_image(DIR_WS_IMAGES . $category['categories_image'], $category['categories_name'], HEADING_IMAGE_WIDTH, HEADING_IMAGE_HEIGHT) . "</div>\n";
+      echo '<div class="headingImage">' .  tep_image(DIR_WS_IMAGES . $category['categories_image'], $category['categories_name'], HEADING_IMAGE_WIDTH, HEADING_IMAGE_HEIGHT) . "</div>\n";
     }
     if ($category['categories_description']) {
-      echo '      <div class="pageHeadingDescription">' . nl2br($category['categories_description']) . "</div>\n";
+      echo '<div class="headingDescription">' . nl2br($category['categories_description']) . "</div>\n";
     }
+    // ƥ꡼
     if (isset($cPath) && ereg('_', $cPath)) {
-// check to see if there are deeper categories within the current category
       $display_category_id = array_reverse($cPath_array);
       include(DIR_WS_MODULES . FILENAME_CATEGORIES);
     } else {
       $display_category_id = $current_category_id;
       include(DIR_WS_MODULES . FILENAME_CATEGORIES);
     }
-?>
-<?php $recommended_products_category_id = $current_category_id; include(DIR_WS_MODULES . FILENAME_RECOMMENDATION); ?>
-<?php $new_products_category_id = $current_category_id; include(DIR_WS_MODULES . FILENAME_NEW_PRODUCTS); ?>
-<?php
+    // Ź
+    $recommended_products_category_id = $current_category_id;
+    include(DIR_WS_MODULES . FILENAME_RECOMMENDATION);
+    // 徦
+    $new_products_category_id = $current_category_id;
+    include(DIR_WS_MODULES . FILENAME_NEW_PRODUCTS);
+
   } elseif ($category_depth == 'products' || $HTTP_GET_VARS['manufacturers_id']) {
-    // ʰڡ
+// ʰڡ
     $define_list = array();
     $define_list['PRODUCT_LIST_MODEL'] = KN_CFG_PRODUCT_LIST_MODEL;
     $define_list['PRODUCT_LIST_NAME'] = KN_CFG_PRODUCT_LIST_NAME;
@@ -312,8 +339,6 @@ ryuhei@secondbrain.co.jp
       }
     }
 
-// Get the right image for the top-right
-    $image = DIR_WS_IMAGES . 'table_background_list.gif';
     if (isset($HTTP_GET_VARS['manufacturers_id'])) {
       $manufacturer_query = tep_db_query("select manufacturers_name, manufacturers_image from " . TABLE_MANUFACTURERS . " where manufacturers_id = '" . $HTTP_GET_VARS['manufacturers_id'] . "'");
       $manufacturer = tep_db_fetch_array($manufacturer_query);
@@ -328,26 +353,25 @@ ryuhei@secondbrain.co.jp
       $title_description = $category['categories_description'];
     }
 ?>
-      <h1 class="pageHeading"><?php echo $title_name; ?></h1>
+<h2 class="pageHeading"><?php echo $title_name; ?></h2>
+<div id="common">
 <?php
     if ($title_image) {
-      echo '      <div class="pageHeadingImage">' . tep_image(DIR_WS_IMAGES . $title_image, $title_name, HEADING_IMAGE_WIDTH, HEADING_IMAGE_HEIGHT) . "</div>\n";
+      echo '<div class="headingImage">' . tep_image(DIR_WS_IMAGES . $title_image, $title_name, HEADING_IMAGE_WIDTH, HEADING_IMAGE_HEIGHT) . "</div>\n";
     }
     if ($title_description) {
-      echo '      <div class="pageHeadingDescription">' . nl2br($title_description) . "</div>\n";
+      echo '<div class="headingDescription">' . nl2br($title_description) . "</div>\n";
     }
       
     $display_category_id = $current_category_id;
     if (!isset($HTTP_GET_VARS['manufacturers_id'])) {
       include(DIR_WS_MODULES . FILENAME_CATEGORIES);
     }
-?>
-<?php
-// optional Product List Filter
+
     if (PRODUCT_LIST_FILTER > 0) {
       $filterlist_query = tep_db_query($filterlist_sql);
       if (tep_db_num_rows($filterlist_query) > 1) {
-        echo '      <div id="filterSelect"><form>' . TEXT_SHOW . '<select size="1" onChange="if(options[selectedIndex].value) window.location.href=(options[selectedIndex].value)">';
+        echo '<div id="filterSelect"><form>' . TEXT_SHOW . '<select size="1" onChange="if(options[selectedIndex].value) window.location.href=(options[selectedIndex].value)">';
         if (isset($HTTP_GET_VARS['manufacturers_id'])) {
           $arguments = 'manufacturers_id=' . $HTTP_GET_VARS['manufacturers_id'];
         } else {
@@ -376,50 +400,54 @@ ryuhei@secondbrain.co.jp
       }
     }
 
+    // ʰ
     include(DIR_WS_MODULES . FILENAME_PRODUCT_LISTING);
     
   } else {
-  // ȥåץڡ
+// ȥåץڡ
 ?>
-      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
+<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
+<div id="common">
 <?php
-  if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
-  } else {
-?>
-      <div class="greeting"><?php echo tep_customer_greeting(); ?></div>
-<?php
-  }
-  $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_WHATS_NEW'");
-  $shop_info = tep_db_fetch_array($shop_info_query);
-  if (isset($shop_info['shop_info_value']) && tep_not_null($shop_info['shop_info_value'])) {
-    echo '      <div id="siWhatsNew">';
-    if ($shop_info['allow_tags']) {
-      echo $shop_info['shop_info_value'];
-    } else {
-      echo nl2br(htmlspecialchars($shop_info['shop_info_value']));
+    // ʸ
+    if (!defined("KN_CFG_ALLOW_CHECKOUT") || (KN_CFG_ALLOW_CHECKOUT == "true")) {
+      if (KN_CFG_DISPLAY_CUSTOMER_GREETING == "true") {
+        echo '<div class="greeting">' . tep_customer_greeting() . '</div>';
+      }
     }
-    echo '      </div>';
+    // 
+    $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, allow_edit_title, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_WHATS_NEW'");
+    $shop_info = tep_db_fetch_array($shop_info_query);
+    if (isset($shop_info['shop_info_value']) && tep_not_null($shop_info['shop_info_value'])) {
+      if ($shop_info['allow_edit_title']) {
+        echo '<h3>' . $shop_info['shop_info_title'] . "</h3>\n";
+      }
+      echo '<div id="whatsNew">';
+      if ($shop_info['allow_tags']) {
+        echo $shop_info['shop_info_value'];
+      } else {
+        echo nl2br(htmlspecialchars($shop_info['shop_info_value']));
+      }
+      echo "</div>\n";
+    }
+    // ƥ꡼
+    $display_category_id = $current_category_id;
+    include(DIR_WS_MODULES . FILENAME_CATEGORIES);
+    // Ź
+    include(DIR_WS_MODULES . FILENAME_RECOMMENDATION);
+    // 徦
+    include(DIR_WS_MODULES . FILENAME_NEW_PRODUCTS);
   }
 ?>
-<?php $display_category_id = $current_category_id; include(DIR_WS_MODULES . FILENAME_CATEGORIES); ?>
-<?php include(DIR_WS_MODULES . FILENAME_RECOMMENDATION); ?>
-<?php include(DIR_WS_MODULES . FILENAME_NEW_PRODUCTS); ?>
-<?php
-  }
-?>
-    </td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
-<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-
-<!-- footer //-->
-<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
 </div>
+</div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
