@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: login.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
+  $Id: login.php,v 1.5 2006/08/07 06:21:15 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -77,14 +77,15 @@
 
   $breadcrumb->add(NAVBAR_TITLE, tep_href_link(FILENAME_LOGIN, '', 'SSL'));
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
 <title><?php echo TITLE; ?></title>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_LOGIN, 0, strrpos(FILENAME_LOGIN, '.'));?>.css">
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_LOGIN, 0, strrpos(FILENAME_LOGIN, '.'));?>.css" media="screen,print" />
 <script language="javascript"><!--
 function session_win() {
   window.open("<?php echo tep_href_link(FILENAME_INFO_SHOPPING_CART); ?>","info_shopping_cart","height=460,width=430,toolbar=no,statusbar=no,scrollbars=yes").focus();
@@ -92,36 +93,51 @@ function session_win() {
 //--></script>
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+<!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-<!-- body //-->
-<table id="contents">
-  <tr>
-<!-- left_navigation //-->
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents"><?php echo tep_draw_form('login', tep_href_link(FILENAME_LOGIN, 'action=process', 'SSL')); ?>
-      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
+<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
+<?php
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
+  }
+?>
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
+<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
+<div id="login">
 <?php
   if (isset($HTTP_GET_VARS['login']) && ($HTTP_GET_VARS['login'] == 'fail')) {
-    $info_message = TEXT_LOGIN_ERROR;
+    echo '<p class="caution">' . TEXT_LOGIN_ERROR . "</p>\n";
   } elseif ($cart->count_contents()) {
-    $info_message = TEXT_VISITORS_CART;
+    echo '<p class="caution">' . TEXT_VISITORS_CART . "</p>\n";
   }
 
-  if (isset($info_message)) {
-?>
-<div class="infoLine"><span class="infoMessage"><?php echo $info_message; ?></span></div>
-<?php
-  }
   $cssid = 'newCustomer';
   $contentbox_header = HEADING_NEW_CUSTOMER;
 
   $contentbox_contents = array();
-  $contentbox_contents[] = array('text' => TEXT_NEW_CUSTOMER . '<br>' . TEXT_NEW_CUSTOMER_INTRODUCTION);
+  $contentbox_contents[] = array('text' => '<p>' . TEXT_NEW_CUSTOMER . '<br />' . TEXT_NEW_CUSTOMER_INTRODUCTION . '</p>');
 
   $contentbox_footer = '<a href="' . tep_href_link(FILENAME_CREATE_ACCOUNT, '', 'SSL') . '">' . tep_image_button('button_continue.gif', IMAGE_BUTTON_CONTINUE) . '</a>';
 
@@ -132,36 +148,32 @@ function session_win() {
 
   $contentbox_contents = array();
   $contentslist = "<table>\n" . 
-                      "  <tr>\n" . 
-                      '    <td class="tableHeading">' . ENTRY_EMAIL_ADDRESS . "</td>\n" . 
-                      '    <td>' . tep_draw_input_field('email_address') . "</td>\n" . 
-                      "  </tr>\n" . 
-                      "  <tr>\n" . 
-                      '    <td class="tableHeading">' . ENTRY_PASSWORD . "</td>\n" . 
-                      '    <td>' . tep_draw_password_field('password') . "</td>\n" . 
-                      "  </tr>\n" . 
-                      "  <tr>\n" . 
-                      '    <td colspan="2"><a href="' . tep_href_link(FILENAME_PASSWORD_FORGOTTEN, '', 'SSL') . '">' . TEXT_PASSWORD_FORGOTTEN . "</a></td>\n" . 
-                      "  </tr>\n" . 
-                      "</table>\n";
-  $contentbox_contents[] = array('text' => $contentslist);
+                      "<tr>\n" . 
+                      '<th>' . ENTRY_EMAIL_ADDRESS . "</th>\n" . 
+                      '<td>' . tep_draw_input_field('email_address') . "</td>\n" . 
+                      "</tr>\n" . 
+                      "<tr>\n" . 
+                      '<th>' . ENTRY_PASSWORD . "</th>\n" . 
+                      '<td>' . tep_draw_password_field('password') . "</td>\n" . 
+                      "</tr>\n" . 
+                      "</table>\n".
+                      '<p><a href="' . tep_href_link(FILENAME_PASSWORD_FORGOTTEN, '', 'SSL') . '">' . TEXT_PASSWORD_FORGOTTEN . "</a></p>\n" . 
+                      '<div class="buttonLine">' . "\n" . 
+                      '<p class="buttonRight">' . tep_image_submit('button_login.gif', IMAGE_BUTTON_LOGIN) . "</p>\n" . 
+                      "</div>\n";
+  $contentbox_contents[] = array('form' => tep_draw_form('login', tep_href_link(FILENAME_LOGIN, 'action=process', 'SSL')) ,'text' => $contentslist);
   
-  $contentbox_footer = tep_image_submit('button_login.gif', IMAGE_BUTTON_LOGIN);
-
-  new contentBox($cssid, $contentbox_contents, $contentbox_header, $contentbox_footer);
+  new contentBox($cssid, $contentbox_contents, $contentbox_header);
 ?>
-    </form></td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
-<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-<!-- footer //-->
-<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
 </div>
+</div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
