@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: password_forgotten.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
+  $Id: password_forgotten.php,v 1.5 2006/08/07 06:21:15 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -43,57 +43,72 @@
   $breadcrumb->add(NAVBAR_TITLE_1, tep_href_link(FILENAME_LOGIN, '', 'SSL'));
   $breadcrumb->add(NAVBAR_TITLE_2, tep_href_link(FILENAME_PASSWORD_FORGOTTEN, '', 'SSL'));
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
 <title><?php echo TITLE; ?></title>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_PASSWORD_FORGOTTEN, 0, strrpos(FILENAME_PASSWORD_FORGOTTEN, '.'));?>.css">
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_PASSWORD_FORGOTTEN, 0, strrpos(FILENAME_PASSWORD_FORGOTTEN, '.'));?>.css" media="screen,print" />
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+<!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-
-<!-- body //-->
-<table id="contents">
-  <tr>
-<!-- left_navigation //-->
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents"><?php echo tep_draw_form('password_forgotten', tep_href_link(FILENAME_PASSWORD_FORGOTTEN, 'action=process', 'SSL')); ?>
-      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
-      <div class="passwordForgottenForm">
-        <span class="passwordForgottenHeading"><?php echo ENTRY_FORGOTTEN_EMAIL_ADDRESS; // 2003.03.06 nagata Edit Japanese osCommerce ?></span>
-        <span class="passwordForgottenInputBox"><?php echo tep_draw_input_field('email_address', '', 'maxlength="96"'); ?></span>
-      </div>
-      <table>
-        <tr class="buttonLine">
-          <td class="buttonLeft"><a href="<?php echo tep_href_link(FILENAME_LOGIN, '', 'SSL') . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></td>
-          <td class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></td>
-        </tr>
-      </table>
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
+<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
 <?php
-  if (isset($HTTP_GET_VARS['email']) && ($HTTP_GET_VARS['email'] == 'nonexistent')) {
-    echo '      <div class="infoLine"><span class="infoMessage">' .  TEXT_NO_EMAIL_ADDRESS_FOUND . '</span></div>' . "\n";
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
   }
 ?>
-    </form></td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
-<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-<!-- footer //-->
-<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
+<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
+<div id="common">
+<?php
+  echo tep_draw_form('password_forgotten', tep_href_link(FILENAME_PASSWORD_FORGOTTEN, 'action=process', 'SSL')) . "\n";
+
+  if (isset($HTTP_GET_VARS['email']) && ($HTTP_GET_VARS['email'] == 'nonexistent')) {
+    echo '<p class="caution">' .  TEXT_NO_EMAIL_ADDRESS_FOUND . '</p>' . "\n";
+  }
+?>
+<p><?php echo ENTRY_FORGOTTEN_EMAIL_ADDRESS . tep_draw_input_field('email_address', '', 'maxlength="96"'); ?></p>
+<div class="buttonLine">
+<p class="buttonLeft"><a href="<?php echo tep_href_link(FILENAME_LOGIN, '', 'SSL') . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
+<p class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
 </div>
+</form>
+</div>
+</div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php
