@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: product_info.php,v 1.5 2006/03/27 06:05:35 ryu Exp $
+  $Id: product_info.php,v 1.7 2006/08/07 06:21:15 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -30,14 +30,13 @@
     $product_info_title = TITLE . ' : ' . $product_info['products_name'];
     if ($product_info['products_description2']) {
       if (mb_strlen($product_info['products_description2']) > 200) {
-        $meta_products_description2 = mb_substr(@strip_tags($product_info['products_description2']), 0, 200);
+        $meta_description = mb_substr(@strip_tags($product_info['products_description2']), 0, 200);
       } else {
-        $meta_products_description2 = @strip_tags($product_info['products_description2']);
+        $meta_description = @strip_tags($product_info['products_description2']);
       }
-      $meta_description = '<meta name="Description" content="' . $meta_products_description2 . '">' . "\n";
     }
     if ($product_info['products_keywords']) {
-      $meta_keywords = '<meta name="Keywords" content="' . implode(",", explode(" ", $product_info['products_keywords'])) . '">' . "\n";
+      $meta_keywords = implode(",", explode(" ", $product_info['products_keywords']));
     }
     if ((KN_CFG_CONTACT_PRICE != 0) && ($product_info['products_price'] == KN_CFG_CONTACT_PRICE)) {
       $please_contact_us = true;
@@ -49,15 +48,17 @@
     }
   }
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
 <title><?php echo $product_info_title; ?></title>
-<?php echo $meta_description . $meta_keywords; ?>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_PRODUCT_INFO, 0, strrpos(FILENAME_PRODUCT_INFO, '.'));?>.css">
+<meta name="description" content="<?php echo $meta_description; ?>" />
+<meta name="keywords" content="<?php echo $meta_keywords; ?>" />
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_PRODUCT_INFO, 0, strrpos(FILENAME_PRODUCT_INFO, '.'));?>.css" media="screen,print" />
 <script language="javascript"><!--
 function popupWindow(url) {
   window.open(url,'popupWindow','toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=no,resizable=yes,copyhistory=no,width=100,height=100,screenX=150,screenY=150,top=150,left=150')
@@ -65,35 +66,53 @@ function popupWindow(url) {
 //--></script>
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+<!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-
-<!-- body //-->
-<table id="contents">
-  <tr>
-<!-- left_navigation //-->
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents"><?php echo tep_draw_form('cart_quantity', tep_href_link(FILENAME_PRODUCT_INFO, tep_get_all_get_params(array('action')) . 'action=add_product')); ?>
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
+<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
+<?php
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
+  }
+?>
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
 <?php
   if ($no_product_info) {
     // ʤʤȤ
 ?>
-      <div class="noData"><?php echo TEXT_PRODUCT_NOT_FOUND; ?></div>
-      <table>
-        <tr class="buttonLine">
-          <td class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_DEFAULT); ?>"><?php echo tep_image_button('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></a></td>
-        </tr>
-      </table>
+<div id="productInfo">
+<p class="noData"><?php echo TEXT_PRODUCT_NOT_FOUND; ?></p>
+<div class="buttonLine">
+<p class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_DEFAULT); ?>"><?php echo tep_image_button('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></a></p>
+</div>
+</div>
 <?php
   } else {
     tep_db_query("update " . TABLE_PRODUCTS_DESCRIPTION . " set products_viewed = products_viewed+1 where products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and language_id = '" . $languages_id . "'");
 ?>
-      <div id="productInformation">
-      <h1 class="pName"><?php echo $product_info['products_name']; ?></h1>
+<div id="productInfo">
+<h2 class="pageHeading"><?php echo $product_info['products_name']; ?></h2>
 <?php
     if ((KN_CFG_USE_SUBTITLE == 'true') && ($product_info['products_subtitle'])) {
     	$products_subtitle = '<span class="pSubtitle">' . TEXT_PRODUCTS_SUBTITLE . $product_info['products_subtitle'] . '</span>';
@@ -106,67 +125,62 @@ function popupWindow(url) {
     	$products_series_title = '';
     }
     if (tep_not_null($products_subtitle) and tep_not_null($products_series_title)) {
-      echo '      <h2 class="pSubtitleSeriesTitle">' . $products_subtitle . ' ' . $products_series_title . '</h2>' . "\n";
+      echo '<p>' . $products_subtitle . ' ' . $products_series_title . '</p>' . "\n";
     } elseif (tep_not_null($products_subtitle)) {
-      echo '      <h2 class="pSubtitleSeriesTitle">' . $products_subtitle . '</h2>' . "\n";
+      echo '<p>' . $products_subtitle . '</p>' . "\n";
     } elseif (tep_not_null($products_series_title)) {
-      echo '      <h2 class="pSubtitleSeriesTitle">' . $products_series_title . '</h2>' . "\n";
+      echo '<p>' . $products_series_title . '</p>' . "\n";
     }
+    echo tep_draw_form('cart_quantity', tep_href_link(FILENAME_PRODUCT_INFO, tep_get_all_get_params(array('action')) . 'action=add_product'));
 
     if (tep_not_null($product_info['products_image'])) {
 ?>
-      <div class="pImage">
+<div class="pImage">
 <script language="javascript"><!--
-document.write('<?php echo '<a href="javascript:popupWindow(\\\'' . tep_href_link(FILENAME_POPUP_IMAGE, 'pID=' . $product_info['products_id']) . '\\\')">' . tep_image(DIR_WS_IMAGES . $product_info['products_image'], addslashes($product_info['products_name']), SUBCATEGORY_IMAGE_WIDTH, SUBCATEGORY_IMAGE_HEIGHT) . '<br>' . TEXT_CLICK_TO_ENLARGE . '</a>'; ?>');
+document.write('<?php echo '<a href="javascript:popupWindow(\\\'' . tep_href_link(FILENAME_POPUP_IMAGE, 'pID=' . $product_info['products_id']) . '\\\')">' . tep_image(DIR_WS_IMAGES . $product_info['products_image'], addslashes($product_info['products_name']), SUBCATEGORY_IMAGE_WIDTH, SUBCATEGORY_IMAGE_HEIGHT) . '<br />' . TEXT_CLICK_TO_ENLARGE . '</a>'; ?>');
 //--></script>
 <noscript>
-<?php echo '<a href="' . tep_href_link(DIR_WS_IMAGES . $product_info['products_image']) . '">' . tep_image(DIR_WS_IMAGES . $product_info['products_image'], $product_info['products_name'], SUBCATEGORY_IMAGE_WIDTH, SUBCATEGORY_IMAGE_HEIGHT) . '<br>' . TEXT_CLICK_TO_ENLARGE . '</a>'; ?>
+<?php echo '<a href="' . tep_href_link(DIR_WS_IMAGES . $product_info['products_image']) . '">' . tep_image(DIR_WS_IMAGES . $product_info['products_image'], $product_info['products_name'], SUBCATEGORY_IMAGE_WIDTH, SUBCATEGORY_IMAGE_HEIGHT) . '<br />' . TEXT_CLICK_TO_ENLARGE . '</a>'; ?>
 </noscript>
 </div>
 <?php
     }
 
+    echo '<dl class="specification">' . "\n";
     if ((KN_CFG_USE_AUTHOR == 'true') && ($product_info['products_author'])) {
-      echo '      <div class="pAuthor"><span class="pInfoHeading">' . TEXT_PRODUCTS_AUTHOR . '</span>' . $product_info['products_author'] . '</div>' . "\n";
+      echo '<dt>' . TEXT_PRODUCTS_AUTHOR . '</dt><dd class="pAuthor">' . $product_info['products_author'] . '</dd>' . "\n";
     }
     if ((KN_CFG_USE_PUBLISHERS == 'true') && ($product_info['products_publishers'])) {
-      echo '      <div class="pPublishers"><span class="pInfoHeading">' . TEXT_PRODUCTS_PUBLISHERS . '</span>' . $product_info['products_publishers'] . '</div>' . "\n";
+      echo '<dt>' . TEXT_PRODUCTS_PUBLISHERS . '</dt><dd class="pPublishers">' . $product_info['products_publishers'] . '</dd>' . "\n";
     }
     if ((KN_CFG_USE_VOLUME == 'true') && ($product_info['products_volume'])) {
-      echo '      <div class="pVolume"><span class="pInfoHeading">' . TEXT_PRODUCTS_VOLUME . '</span>' . $product_info['products_volume'] . '</div>' . "\n";
+      echo '<dt>' . TEXT_PRODUCTS_VOLUME . '</dt><dd class="pVolume">' . $product_info['products_volume'] . '</dd>' . "\n";
     }
     if ((KN_CFG_USE_PUBLISHED == 'true') && ($product_info['products_published'])) {
-      echo '      <div class="pPublished"><span class="pInfoHeading">' . TEXT_PRODUCTS_PUBLISHED . '</span>' . $product_info['products_published'] . '</div>' . "\n";
+      echo '<dt>' . TEXT_PRODUCTS_PUBLISHED . '</dt><dd class="pPublished">' . $product_info['products_published'] . '</dd>' . "\n";
     }
     if ((KN_CFG_USE_ISBN == 'true') && ($product_info['products_isbn'])) {
-      echo '      <div class="poIsbn"><span class="pInfoHeading">' . TEXT_PRODUCTS_ISBN . '</span>' . $product_info['products_isbn'] . '</div>' . "\n";
-    }
-    if ((KN_CFG_USE_WEIGHT == 'true') && ($product_info['products_weight'])) {
-      echo '      <div class="pWeight"><span class="pInfoHeading">' . TEXT_PRODUCTS_WEIGHT . '</span>' . $product_info['products_weight'] . '</div>' . "\n";
+      echo '<dt>' . TEXT_PRODUCTS_ISBN . '</dt><dd class="pIsbn">' . $product_info['products_isbn'] . '</dd>' . "\n";
     }
+    echo '</dl>' . "\n";
+
     if ($product_info['products_description']) {
-      echo '      <div class="pDescription">' . TEXT_PRODUCTS_DESCRIPTION . nl2br(stripslashes($product_info['products_description'])) . '</div>' . "\n";
+      echo '<p class="pDescription">' . TEXT_PRODUCTS_DESCRIPTION . nl2br(stripslashes($product_info['products_description'])) . '</p>' . "\n";
     }
-    if (KN_CFG_USE_REVIEWS == 'true') {
-      $reviews = tep_db_query("select count(*) as count from " . TABLE_REVIEWS . " where products_id = '" . $HTTP_GET_VARS['products_id'] . "'");
-      $reviews_values = tep_db_fetch_array($reviews);
-      if ($reviews_values['count'] > 0) {
-        echo '      <div class="productInfoCurrentReviews"><span class="pInfoHeading">' . TEXT_CURRENT_REVIEWS . '</span>' . $reviews_values['count'] . '</div>' . "\n";
-      }
+    if ((KN_CFG_USE_DESCRIPTION2 == 'true') && ($product_info['products_description2'])) {
+      echo '<p class="pDescription2">' . TEXT_PRODUCTS_DESCRIPTION2 . nl2br(stripslashes($product_info['products_description2'])) . '</p>' . "\n";
     }
 
-    if ((KN_CFG_USE_DESCRIPTION2 == 'true') && ($product_info['products_description2'])) {
-      echo '      <div class="pDescription2">' . TEXT_PRODUCTS_DESCRIPTION2 . nl2br(stripslashes($product_info['products_description2'])) . '</div>' . "\n";
-    }
+    echo '<dl class="specification2">' . "\n";
     $products_attributes_query = tep_db_query("select count(*) as total from " . TABLE_PRODUCTS_OPTIONS . " popt, " . TABLE_PRODUCTS_ATTRIBUTES . " patrib where patrib.products_id='" . (int)$HTTP_GET_VARS['products_id'] . "' and patrib.options_id = popt.products_options_id and popt.language_id = '" . $languages_id . "'");
     $products_attributes = tep_db_fetch_array($products_attributes_query);
     if ($products_attributes['total'] > 0) {
-      echo '<div class="pOptionsList"><div class="pOptionsListCaption">' . TEXT_PRODUCT_OPTIONS . '</div>' . "\n";
+      echo '<dt>' . TEXT_PRODUCT_OPTIONS . '</dt>' . "\n";
       $products_options_name_query = tep_db_query("select distinct popt.products_options_id, popt.products_options_name from " . TABLE_PRODUCTS_OPTIONS . " popt, " . TABLE_PRODUCTS_ATTRIBUTES . " patrib where patrib.products_id='" . (int)$HTTP_GET_VARS['products_id'] . "' and patrib.options_id = popt.products_options_id and popt.language_id = '" . $languages_id . "'");
       while ($products_options_name = tep_db_fetch_array($products_options_name_query)) {
         $selected = 0;
         $products_options_array = array();
-        echo '<div class="pOptions"><span class="pInfoHeading">' . $products_options_name['products_options_name'] . ':</span>';
+        echo '<dd class="pOptions">' . $products_options_name['products_options_name'];
         $products_options_query = tep_db_query("select pov.products_options_values_id, pov.products_options_values_name, pa.options_values_price, pa.price_prefix from " . TABLE_PRODUCTS_ATTRIBUTES . " pa, " . TABLE_PRODUCTS_OPTIONS_VALUES . " pov where pa.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and pa.options_id = '" . $products_options_name['products_options_id'] . "' and pa.options_values_id = pov.products_options_values_id and pov.language_id = '" . $languages_id . "'");
         while ($products_options = tep_db_fetch_array($products_options_query)) {
           $products_options_array[] = array('id' => $products_options['products_options_values_id'], 'text' => $products_options['products_options_values_name']);
@@ -175,72 +189,79 @@ document.write('<?php echo '<a href="javascript:popupWindow(\\\'' . tep_href_lin
           }
         }
         echo tep_draw_pull_down_menu('id[' . $products_options_name['products_options_id'] . ']', $products_options_array, $cart->contents[$HTTP_GET_VARS['products_id']]['attributes'][$products_options_name['products_options_id']]);
-        echo '</div>';
+        echo "</dd>\n";
+      }
+    }
+    if ((KN_CFG_USE_WEIGHT == 'true') && ($product_info['products_weight'])) {
+      echo '<dt>' . TEXT_PRODUCTS_WEIGHT . '</dt><dd class="pWeight">' . $product_info['products_weight'] . '</dd>' . "\n";
+    }
+    if (KN_CFG_USE_REVIEWS == 'true') {
+      $reviews = tep_db_query("select count(*) as count from " . TABLE_REVIEWS . " where products_id = '" . $HTTP_GET_VARS['products_id'] . "'");
+      $reviews_values = tep_db_fetch_array($reviews);
+      if ($reviews_values['count'] > 0) {
+        echo '<dt>' . TEXT_CURRENT_REVIEWS . '</dt><dd class="pReviews">' . $reviews_values['count'] . '</dd>' . "\n";
       }
-      echo '</div>';
     }
     if ($product_info['products_model']) {
-      echo '      <div class="pModel"><span class="pInfoHeading">' . TEXT_PRODUCTS_MODEL . '</span>' . $product_info['products_model'] . '</div>' . "\n";
+      echo '<dt>' . TEXT_PRODUCTS_MODEL . '</dt><dd class="pModel">' . $product_info['products_model'] . '</dd>' . "\n";
     }
-
     if ($please_contact_us) {
       if (defined("KN_CFG_CONTACT_BY_EMAIL") && (KN_CFG_CONTACT_BY_EMAIL == 'false')) {
-        echo '      <div class="pPrice">' . KN_CFG_CONTACT_PRICE_TEXT . '</div>' . "\n";
+        echo '<dt>' . TEXT_PRODUCTS_PRICE . '</dt><dd class="pPrice">' . KN_CFG_CONTACT_PRICE_TEXT . '</dd>' . "\n";
       } else {
-        echo '      <div class="pPrice"><a href="mailto:' . STORE_OWNER_EMAIL_ADDRESS . '?subject=' . $email_subject . '&body=' . $email_body . '">' . KN_CFG_CONTACT_PRICE_TEXT . '</a></div>' . "\n";
+        echo '<dt>' . TEXT_PRODUCTS_PRICE . '</dt><dd class="pPrice"><a href="mailto:' . STORE_OWNER_EMAIL_ADDRESS . '?subject=' . $email_subject . '&body=' . $email_body . '">' . KN_CFG_CONTACT_PRICE_TEXT . '</a></dd>' . "\n";
       }
     } else {
       if ($new_price = tep_get_products_special_price($product_info['products_id'])) {
-        echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span><s>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</s> <span class="pSpecialPrice">' . $currencies->display_price($new_price, tep_get_tax_rate($product_info['products_tax_class_id'])) . '</span></div>' . "\n";
+        echo '<dt>' . TEXT_PRODUCTS_PRICE . '</dt><dd class="pPrice"><del>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</del> <span class="specialPrice">' . $currencies->display_price($new_price, tep_get_tax_rate($product_info['products_tax_class_id'])) . '</span></dd>' . "\n";
       } else {
-        echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</div>' . "\n";
+        echo '<dt>' . TEXT_PRODUCTS_PRICE . '</dt><dd class="pPrice">' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</dd>' . "\n";
       }
     }
+    echo '</dl>' . "\n";
 ?>
-      <table>
-        <tr class="buttonLine">
+<div class="buttonLine">
 <?php
     if (KN_CFG_USE_REVIEWS == 'true') {
       $reviews = tep_db_query("select count(*) as count from " . TABLE_REVIEWS . " where products_id = '" . $HTTP_GET_VARS['products_id'] . "'");
       $reviews_values = tep_db_fetch_array($reviews);
       if ($reviews_values['count'] > 0) {
 ?>
-          <td class="buttonLeft"><a href="<?php echo tep_href_link(FILENAME_PRODUCT_REVIEWS, substr(tep_get_all_get_params(), 0, -1)); ?>"><?php echo tep_image_button('button_reviews.gif', IMAGE_BUTTON_REVIEWS); ?></a></td>
+<p class="buttonLeft"><a href="<?php echo tep_href_link(FILENAME_PRODUCT_REVIEWS, substr(tep_get_all_get_params(), 0, -1)); ?>"><?php echo tep_image_button('button_reviews.gif', IMAGE_BUTTON_REVIEWS); ?></a></p>
 <?php
       }
     }
     if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
 ?>
-          <td class="buttonRight"></td>
+<p class="buttonRight"></p>
 <?php
     } else {
       if ($please_contact_us) {
 ?>
-          <td class="buttonRight"></td>
+<p class="buttonRight"></p>
 <?php
       } else {
 ?>
-          <td class="buttonRight"><?php echo tep_draw_hidden_field('products_id', $product_info['products_id']) . tep_image_submit('button_in_cart.gif', IMAGE_BUTTON_IN_CART); ?></td>
+<p class="buttonRight"><?php echo tep_draw_hidden_field('products_id', $product_info['products_id']) . tep_image_submit('button_in_cart.gif', IMAGE_BUTTON_IN_CART); ?></p>
 <?php
       }
     }
 ?>
-        </tr>
-      </table>
+</div>
 <?php
     if ((KN_CFG_USE_URL == 'true') && (tep_not_null($product_info['products_url']))) {
-      echo '      <div class="productMoreInfo">' . sprintf(TEXT_MORE_INFORMATION, tep_href_link(FILENAME_REDIRECT, 'action=url&goto=' . urlencode($product_info['products_url']), 'NONSSL', true, false)) . '</div>' . "\n";
+      echo '<p>' . sprintf(TEXT_MORE_INFORMATION, tep_href_link(FILENAME_REDIRECT, 'action=url&goto=' . urlencode($product_info['products_url']), 'NONSSL', true, false)) . '</p>' . "\n";
     }
 
     if ((KN_CFG_USE_DATE_AVAILABLE == 'true') && ($product_info['products_date_available'] > date('Y-m-d H:i:s'))) {
-      echo '      <div class="pDateAvailable">' . sprintf(TEXT_DATE_AVAILABLE, tep_date_long($product_info['products_date_available'])) . '</div>' . "\n";
+      echo '<p class="caution">' . sprintf(TEXT_DATE_AVAILABLE, tep_date_long($product_info['products_date_available'])) . '</p>' . "\n";
     } else {
       if (KN_CFG_DATE_ADDED_DISPLAY == 'true') {
-      echo '      <div class="pDateAdded">' . sprintf(TEXT_DATE_ADDED, tep_date_long($product_info['products_date_added'])) . '</div>' . "\n";
+      echo '<p>' . sprintf(TEXT_DATE_ADDED, tep_date_long($product_info['products_date_added'])) . '</p>' . "\n";
       }
     }
 
-    echo '</div>';
+    echo "</form>\n";
 
     if ((KN_CFG_GETA_ENABLED == 'true') && (KN_CFG_GETA_PRODUCTS_ENABLED == 'true')) {
       //GETAե
@@ -256,20 +277,19 @@ document.write('<?php echo '<a href="javascript:popupWindow(\\\'' . tep_href_lin
         include(DIR_WS_MODULES . FILENAME_ALSO_PURCHASED_PRODUCTS);
       }
     }
+?>
+</div>
+<?php
   }
 ?>
-    </form></td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
-<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-<!-- footer //-->
-<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
 </div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
