@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: shopping_cart.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
+  $Id: shopping_cart.php,v 1.5 2006/08/07 06:21:15 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -23,32 +23,54 @@
 
   $breadcrumb->add(NAVBAR_TITLE, tep_href_link(FILENAME_SHOPPING_CART));
 ?>
-<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html <?php echo HTML_PARAMS; ?>>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
+<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
+<meta http-equiv="content-style-type" content="text/css" />
 <title><?php echo TITLE; ?></title>
-<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
-<link rel="stylesheet" type="text/css" href="general.css">
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_SHOPPING_CART, 0, strrpos(FILENAME_SHOPPING_CART, '.'));?>.css">
+<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
+<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
+<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_SHOPPING_CART, 0, strrpos(FILENAME_SHOPPING_CART, '.'));?>.css" media="screen,print" />
 </head>
 <body>
-<div id="bodyWrapper">
-<!-- header //-->
+<!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
-<!-- header_eof //-->
-<!-- body //-->
-<table id="contents">
-  <tr>
-<!-- left_navigation //-->
+<!-- /header -->
+<hr />
+<!-- contents -->
+<div id="contents">
+<!-- left_contents -->
 <?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
-<!-- left_navigation_eof //-->
-<!-- body_text //-->
-    <td id="mainContents">
-      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
+<!-- /left_contents -->
+<hr />
+<!-- right_contents -->
+<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
+<!-- /right_contents -->
+<hr />
+<!-- main_contents -->
+<?php
+  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsRL">' . "\n";
+    } else {
+      echo '<div id="mainContentsR">' . "\n";
+    }
+  } else {
+    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
+      echo '<div id="mainContentsL">' . "\n";
+    } else {
+      echo '<div id="mainContents">' . "\n";
+    }
+  }
+?>
+<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
+<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
+<div id="shoppingCart">
+<p class="cartInfo"><?php echo TEXT_UPDATE_CART_INFO; ?></p>
 <?php
   if ($cart->count_contents() > 0) {
-    echo tep_draw_form('cart_quantity', tep_href_link(FILENAME_SHOPPING_CART, 'action=update_product'));
+    echo tep_draw_form('cart_quantity', tep_href_link(FILENAME_SHOPPING_CART, 'action=update_product')) . "\n";
     
     $any_out_of_stock = 0;
     $products = $cart->get_products();
@@ -56,7 +78,7 @@
 // Push all attributes information in an array
       if (isset($products[$i]['attributes'])) {
         while (list($option, $value) = each($products[$i]['attributes'])) {
-          echo tep_draw_hidden_field('id[' . $products[$i]['id'] . '][' . $option . ']', $value);
+          echo tep_draw_hidden_field('id[' . $products[$i]['id'] . '][' . $option . ']', $value) . "\n";
           $attributes = tep_db_query("select popt.products_options_name, poval.products_options_values_name, pa.options_values_price, pa.price_prefix
                                       from " . TABLE_PRODUCTS_OPTIONS . " popt, " . TABLE_PRODUCTS_OPTIONS_VALUES . " poval, " . TABLE_PRODUCTS_ATTRIBUTES . " pa
                                       where pa.products_id = '" . $products[$i]['id'] . "'
@@ -79,60 +101,52 @@
 
     require(DIR_WS_MODULES. 'order_details.php');
 ?>
-      <div class="cartSubTotal"><?php echo SUB_TITLE_SUB_TOTAL; ?> <?php echo $currencies->format($cart->show_total()); ?></div>
+<p class="cartSubTotal"><?php echo SUB_TITLE_SUB_TOTAL; ?> <?php echo $currencies->format($cart->show_total()); ?></p>
 <?php
     if ($any_out_of_stock == 1) {
       if (STOCK_ALLOW_CHECKOUT == 'true') {
 ?>
-      <div class="cartStockWarning"><?php echo OUT_OF_STOCK_CAN_CHECKOUT; ?></div>
+<p class="caution"><?php echo OUT_OF_STOCK_CAN_CHECKOUT; ?></p>
 <?php
       } else {
 ?>
-      <div class="cartStockWarning"><?php echo OUT_OF_STOCK_CANT_CHECKOUT; ?></div>
+<p class="caution"><?php echo OUT_OF_STOCK_CANT_CHECKOUT; ?></p>
 <?php
       }
     }
 ?>
-      <table>
-        <tr class="buttonLine">
-          <td class="buttonLeft"><?php echo tep_image_submit('button_update_cart.gif', IMAGE_BUTTON_UPDATE_CART); ?></td>
+<div class="buttonLine">
+<p class="buttonLeft"><?php echo tep_image_submit('button_update_cart.gif', IMAGE_BUTTON_UPDATE_CART); ?></p>
 <?php
     $back = sizeof($navigation->path)-2;
     if (isset($navigation->path[$back])) {
 ?>
-          <td class="buttonCenter"><?php echo '<a href="' . tep_href_link($navigation->path[$back]['page'], tep_array_to_string($navigation->path[$back]['get'], array('action')), $navigation->path[$back]['mode']) . '">' . tep_image_button('button_continue_shopping.gif', IMAGE_BUTTON_CONTINUE_SHOPPING) . '</a>'; ?></td>
+<p class="buttonCenter"><?php echo '<a href="' . tep_href_link($navigation->path[$back]['page'], tep_array_to_string($navigation->path[$back]['get'], array('action')), $navigation->path[$back]['mode']) . '">' . tep_image_button('button_continue_shopping.gif', IMAGE_BUTTON_CONTINUE_SHOPPING) . '</a>'; ?></p>
 <?php
     }
 ?>
-          <td class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL'); ?>"><?php echo tep_image_button('button_checkout.gif', IMAGE_BUTTON_CHECKOUT); ?></td>
-        </tr>
-      </table>
-      <div class="cartInfo"><?php echo TEXT_UPDATE_CART_INFO; // 2003.02.27 nagata Add Japanese osCommerce ?></div>
-      </form>
+<p class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL'); ?>"><?php echo tep_image_button('button_checkout.gif', IMAGE_BUTTON_CHECKOUT); ?></p>
+</div>
+</form>
 <?php
   } else {
 ?>
-      <div class="noData"><?php echo TEXT_CART_EMPTY; ?></div>
-      <table>
-        <tr class="buttonLine">
-          <td class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_DEFAULT); ?>"><?php echo tep_image_button('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></a></td>
-        </tr>
-      </table>
+<p class="noData"><?php echo TEXT_CART_EMPTY; ?></p>
+<div class="buttonLine">
+<p class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_DEFAULT); ?>"><?php echo tep_image_button('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></a></p>
+</div>
 <?php
   }
 ?>
-    </td>
-<!-- body_text_eof //-->
-<!-- right_navigation //-->
-<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
-<!-- right_navigation_eof //-->
-  </tr>
-</table>
-<!-- body_eof //-->
-<!-- footer //-->
-<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
-<!-- footer_eof //-->
 </div>
+</div>
+<!-- /main_contents -->
+<hr />
+<!-- footer -->
+<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
+<!-- /footer -->
+</div>
+<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
